////////////////////////////////////////////////////////////////////////////////
///	\file		MW500_vars.inc
///
///	\brief		Definition of all inverter parameters and the methods to access
///				these parameters.
///
///	\version	01
///
///	\author		WEG
////////////////////////////////////////////////////////////////////////////////

VARIABLE g_wParNumber
{
	LABEL		"Parameter Number";
	CLASS		LOCAL;
	TYPE		UNSIGNED_INTEGER(2);
}

COMMAND WRITE_PAR_NUMBER
{
	SLOT 0;
	INDEX 48;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST { g_wParNumber }
		REPLY { }

	}
}
VARIABLE P0000
{
	LABEL "P0000 Access to Parameters|es|P0000 Acceso Parmetro";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 9999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0000
	}
}

COMMAND READ_P0000
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0000 }
	}
}

METHOD SET_PAR_NUMBER_0000
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 0;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0000 LIKE READ_P0000
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 0, P0000 }
		REPLY { }
	}
}

VARIABLE P0001
{
	LABEL "P0001 Speed Reference|es|P0001 Referencia Velocidad";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0001
	}
}

COMMAND READ_P0001
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0001 }
	}
}

METHOD SET_PAR_NUMBER_0001
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0002
{
	LABEL "P0002 Motor Speed |es|P0002 Velocidad Motor ";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0002
	}
}

COMMAND READ_P0002
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0002 }
	}
}

METHOD SET_PAR_NUMBER_0002
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 2;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0003
{
	LABEL "P0003 Motor Current |es|P0003 Velocidad Motor ";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "A";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0003
	}
}

COMMAND READ_P0003
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0003 }
	}
}

METHOD SET_PAR_NUMBER_0003
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 3;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0004
{
	LABEL "P0004 DC Link Voltage (Ud)|es|P0004 Tensin Bus CC";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 2000;
	}
	CONSTANT_UNIT "V";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0004
	}
}

COMMAND READ_P0004
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0004 }
	}
}

METHOD SET_PAR_NUMBER_0004
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 4;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0005
{
	LABEL "P0005 Motor Frequency |es|P0005 Frecuencia Motor";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0005
	}
}

COMMAND READ_P0005
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0005 }
	}
}

METHOD SET_PAR_NUMBER_0005
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 5;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0006
{
	LABEL "P0006 VFD Status|es|P0006 Estado Convertidor";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Ready|es|Ready (Listo)" },
		{ 1, "Run|es|Run(Ejecucin)" },
		{ 2, "Under voltage|es|Subtensin" },
		{ 3, "Fault|es|Falla" },
		{ 4, "Self-Tuning|es|Autoajuste" },
		{ 5, "Configuration|es|Configuracin" },
		{ 6, "DC-Braking|es|Frenado CC" },
		{ 7, "Sleep State |es|Estado de Reposo" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0006
	}
}

COMMAND READ_P0006
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0006 }
	}
}

METHOD SET_PAR_NUMBER_0006
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 6;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0007
{
	LABEL "P0007 Motor Voltage |es|P0007 Tensin Salida";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 2000;
	}
	CONSTANT_UNIT "V";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0007
	}
}

COMMAND READ_P0007
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0007 }
	}
}

METHOD SET_PAR_NUMBER_0007
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 7;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0009
{
	LABEL "P0009 Motor Torque|es|P0009 Torque(Par) en el Motor";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE -1000;
		MAX_VALUE 1000;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0009
	}
}

COMMAND READ_P0009
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0009 }
	}
}

METHOD SET_PAR_NUMBER_0009
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 9;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0010
{
	LABEL "P0010 Output Power|es|P0010 Potencia de Salida";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 6553.5;
	}
	CONSTANT_UNIT "kW";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0010
	}
}

COMMAND READ_P0010
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0010 }
	}
}

METHOD SET_PAR_NUMBER_0010
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 10;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0011
{
	LABEL "P0011 Power Factor|es|P0011 Factor de Potencia";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0;
		MIN_VALUE -1;
		MAX_VALUE 1;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0011
	}
}

COMMAND READ_P0011
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0011 }
	}
}

METHOD SET_PAR_NUMBER_0011
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 11;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0012
{
	LABEL "P0012 DI8 to DI1 Status|es|P0012 Estado DI8...DI1";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "DI1|es|DI1" },
		{ 0x0002, "DI2|es|DI2" },
		{ 0x0004, "DI3|es|DI3" },
		{ 0x0008, "DI4|es|DI4" },
		{ 0x0010, "DI5|es|DI5" },
		{ 0x0020, "DI6|es|DI6" },
		{ 0x0040, "DI7|es|DI7" },
		{ 0x0080, "DI8|es|DI8" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0012
	}
}

COMMAND READ_P0012
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0012 }
	}
}

METHOD SET_PAR_NUMBER_0012
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 12;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0013
{
	LABEL "P0013 DO5 to DO1 Status|es|P0013 Estado DO5...DO1";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "DO1|es|DO1" },
		{ 0x0002, "DO2|es|DO2" },
		{ 0x0004, "DO3|es|DO3" },
		{ 0x0008, "DO4|es|DO4" },
		{ 0x0010, "DO5|es|DO5" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0013
	}
}

COMMAND READ_P0013
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0013 }
	}
}

METHOD SET_PAR_NUMBER_0013
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 13;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0014
{
	LABEL "P0014 AO1 Value |es|P0014 Valor de AO1";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0014
	}
}

COMMAND READ_P0014
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0014 }
	}
}

METHOD SET_PAR_NUMBER_0014
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 14;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0015
{
	LABEL "P0015 AO2 Value |es|P0015 Valor de AO2";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0015
	}
}

COMMAND READ_P0015
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0015 }
	}
}

METHOD SET_PAR_NUMBER_0015
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 15;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0016
{
	LABEL "P0016 FO % Value |es|P0016 Valor de FO en %";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0016
	}
}

COMMAND READ_P0016
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0016 }
	}
}

METHOD SET_PAR_NUMBER_0016
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 16;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0017
{
	LABEL "P0017 FO Hz Value |es|P0017 Valor de FO en Hz";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 20000;
	}
	CONSTANT_UNIT "Hz";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0017
	}
}

COMMAND READ_P0017
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0017 }
	}
}

METHOD SET_PAR_NUMBER_0017
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 17;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0018
{
	LABEL "P0018 AI1 Value |es|P0018 Valor de AI1";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE -100;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0018
	}
}

COMMAND READ_P0018
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0018 }
	}
}

METHOD SET_PAR_NUMBER_0018
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 18;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0019
{
	LABEL "P0019 AI2 Value |es|P0019 Valor de AI2";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE -100;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0019
	}
}

COMMAND READ_P0019
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0019 }
	}
}

METHOD SET_PAR_NUMBER_0019
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 19;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0020
{
	LABEL "P0020 AI3 Value |es|P0020 Valor de AI3";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE -100;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0020
	}
}

COMMAND READ_P0020
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0020 }
	}
}

METHOD SET_PAR_NUMBER_0020
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 20;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0021
{
	LABEL "P0021 FI % Value |es|P0021 Valor de FI en %";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE -100;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0021
	}
}

COMMAND READ_P0021
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0021 }
	}
}

METHOD SET_PAR_NUMBER_0021
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 21;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0022
{
	LABEL "P0022 FI Hz Value |es|P0022 Valor de FI en Hz";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 20000;
	}
	CONSTANT_UNIT "Hz";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0022
	}
}

COMMAND READ_P0022
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0022 }
	}
}

METHOD SET_PAR_NUMBER_0022
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 22;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0023
{
	LABEL "P0023 Main SW Version|es|P0023 Versin SW Principal";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 1.5;
		MIN_VALUE 0;
		MAX_VALUE 655.35;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0023
	}
}

COMMAND READ_P0023
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0023 }
	}
}

METHOD SET_PAR_NUMBER_0023
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 23;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0024
{
	LABEL "P0024 Sec. SW Version|es|P0024 Versin SW Secundario";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 1.5;
		MIN_VALUE 0;
		MAX_VALUE 655.35;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0024
	}
}

COMMAND READ_P0024
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0024 }
	}
}

METHOD SET_PAR_NUMBER_0024
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 24;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0027
{
	LABEL "P0027 Plug-In Mod. Config.|es|P0027 Config. Mod. Plug-In";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "No Plug-In|es|Sin Plug-In" },
		{ 1, "CFW500-IOS|es|CFW500-IOS" },
		{ 2, "CFW500-IOD|es|CFW500-IOD" },
		{ 3, "CFW500-IOAD|es|CFW500-IOAD" },
		{ 4, "CFW500-IOR|es|CFW500-IOR" },
		{ 5, "CFW500-CUSB|es|CFW500-CUSB" },
		{ 6, "CFW500-CRS232|es|CFW500-CRS232" },
		{ 7, "CFW500-CCAN|es|CFW500-CCAN" },
		{ 8, "CFW500-CPRO500|es|CFW500-CPRO500" },
		{ 9, "CFW500-CRS485|es|CFW500-CRS485" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0027
	}
}

COMMAND READ_P0027
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0027 }
	}
}

METHOD SET_PAR_NUMBER_0027
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 27;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0029
{
	LABEL "P0029 Power HW Config.|es|P0029 Config. HW Potencia";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Identified|es|No Identificado" },
		{ 1, "200-240V / 1,6A|es|200-240V / 1,6A" },
		{ 2, "200-240V / 2,6A|es|200-240V / 2,6A" },
		{ 3, "200-240V / 4,3A|es|200-240V / 4,3A" },
		{ 4, "200-240V / 7,0A|es|200-240V / 7,0A" },
		{ 5, "200-240V / 9,6A|es|200-240V / 9,6A" },
		{ 6, "380-480V / 1,0A|es|380-480V / 1,0A" },
		{ 7, "380-480V / 1,6A|es|380-480V / 1,6A" },
		{ 8, "380-480V / 2,6A|es|380-480V / 2,6A" },
		{ 9, "380-480V / 4,3A|es|380-480V / 4,3A" },
		{ 10, "380-480V / 6,1A|es|380-480V / 6,1A" },
		{ 11, "200-240V / 7,3A|es|200-240V / 7,3A" },
		{ 12, "200-240V / 10,0A|es|200-240V / 10,0A" },
		{ 13, "200-240V / 16,0A|es|200-240V / 16,0A" },
		{ 14, "380-480V / 2,6A|es|380-480V / 2,6A" },
		{ 15, "380-480V / 4,3A|es|380-480V / 4,3A" },
		{ 16, "380-480V / 6,5A|es|380-480V / 6,5A" },
		{ 17, "380-480V / 10,0A|es|380-480V / 10,0A" },
		{ 18, "200-240V / 24,0A|es|200-240V / 24,0A" },
		{ 19, "380-480V / 14,0A|es|380-480V / 14,0A" },
		{ 20, "380-480V / 16,0A|es|380-480V / 16,0A" },
		{ 21, "500-600V / 1,7A|es|500-600V / 1,7A" },
		{ 22, "500-600V / 3,0A|es|500-600V / 3,0A" },
		{ 23, "500-600V / 4,3A|es|500-600V / 4,3A" },
		{ 24, "500-600V / 7,0A|es|500-600V / 7,0A" },
		{ 25, "500-600V / 10,0A|es|500-600V / 10,0A" },
		{ 26, "500-600V / 12,0A|es|500-600V / 12,0A" },
		{ 27, "200-240V / 28,0A|es|200-240V / 28,0A" },
		{ 28, "200-240V / 33,0A|es|200-240V / 33,0A" },
		{ 29, "380-480V / 24,0A|es|380-480V / 24,0A" },
		{ 30, "380-480V / 30,0A|es|380-480V / 30,0A" },
		{ 31, "500-600V / 17,0A|es|500-600V / 17,0A" },
		{ 32, "500-600V / 22,0A|es|500-600V / 22,0A" },
		{ 33, "200-240V / 45,0A|es|200-240V / 45,0A" },
		{ 34, "200-240V / 54,0A|es|200-240V / 54,0A" },
		{ 35, "380-480V / 38,0A|es|380-480V / 38,0A" },
		{ 36, "380-480V / 45,0A|es|380-480V / 45,0A" },
		{ 37, "500-600V / 27,0A|es|500-600V / 27,0A" },
		{ 38, "500-600V / 32,0A|es|500-600V / 32,0A" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0029
	}
}

COMMAND READ_P0029
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0029 }
	}
}

METHOD SET_PAR_NUMBER_0029
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 29;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0030
{
	LABEL "P0030 Heat sink Temperature|es|P0030 Temp. Mdulo";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -20;
		MAX_VALUE 150;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0030
	}
}

COMMAND READ_P0030
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0030 }
	}
}

METHOD SET_PAR_NUMBER_0030
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 30;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0036
{
	LABEL "P0036 Fan Heat sink Speed|es|P0036 Velocidad Ventilador";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 15000;
	}
	CONSTANT_UNIT "rpm";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0036
	}
}

COMMAND READ_P0036
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0036 }
	}
}

METHOD SET_PAR_NUMBER_0036
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 36;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0037
{
	LABEL "P0037 Motor Overload Ixt|es|P0037 Sobrecarga Motor Ixt";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0037
	}
}

COMMAND READ_P0037
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0037 }
	}
}

METHOD SET_PAR_NUMBER_0037
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 37;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0040
{
	LABEL "P0040 PID Process Variable|es|P0040 Variable Proceso PID";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 3000;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0040
	}
}

COMMAND READ_P0040
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0040 }
	}
}

METHOD SET_PAR_NUMBER_0040
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 40;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0041
{
	LABEL "P0041 PID Set point Value|es|P0041 Valor Setpoint PID";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 3000;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0041
	}
}

COMMAND READ_P0041
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0041 }
	}
}

METHOD SET_PAR_NUMBER_0041
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 41;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0045
{
	LABEL "P0045 Fan Enabled Time|es|P0045 Horas Ventil. Ligado";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	CONSTANT_UNIT "h";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0045
	}
}

COMMAND READ_P0045
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0045 }
	}
}

METHOD SET_PAR_NUMBER_0045
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 45;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0047
{
	LABEL "P0047 CONF State|es|P0047 Estado CONF";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0047
	}
}

COMMAND READ_P0047
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0047 }
	}
}

METHOD SET_PAR_NUMBER_0047
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 47;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0048
{
	LABEL "P0048 Present Alarm|es|P0048 Alarma Actual";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0048
	}
}

COMMAND READ_P0048
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0048 }
	}
}

METHOD SET_PAR_NUMBER_0048
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 48;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0049
{
	LABEL "P0049 Present Fault|es|P0049 Falla Actual";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0049
	}
}

COMMAND READ_P0049
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0049 }
	}
}

METHOD SET_PAR_NUMBER_0049
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 49;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0050
{
	LABEL "P0050 Last Fault|es|P0050 ltima Falla";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0050
	}
}

COMMAND READ_P0050
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0050 }
	}
}

METHOD SET_PAR_NUMBER_0050
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 50;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0051
{
	LABEL "P0051 Current At Last Fault|es|P0051 Corriente lt. Falla";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "A";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0051
	}
}

COMMAND READ_P0051
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0051 }
	}
}

METHOD SET_PAR_NUMBER_0051
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 51;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0052
{
	LABEL "P0052 DC Link At Last Fault|es|P0052 Bus CC ltima Falla";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 2000;
	}
	CONSTANT_UNIT "V";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0052
	}
}

COMMAND READ_P0052
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0052 }
	}
}

METHOD SET_PAR_NUMBER_0052
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 52;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0053
{
	LABEL "P0053 Speed At Last Fault|es|P0053 Velocidad lt. Falla";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0053
	}
}

COMMAND READ_P0053
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0053 }
	}
}

METHOD SET_PAR_NUMBER_0053
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 53;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0054
{
	LABEL "P0054 Temp. At Last Fault|es|P0054 Temp. lt. Falla";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -20;
		MAX_VALUE 150;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0054
	}
}

COMMAND READ_P0054
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0054 }
	}
}

METHOD SET_PAR_NUMBER_0054
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 54;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0055
{
	LABEL "P0055 Log. State Last Fault|es|P0055 Estado Lg. lt. Falla";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0055
	}
}

COMMAND READ_P0055
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0055 }
	}
}

METHOD SET_PAR_NUMBER_0055
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 55;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0060
{
	LABEL "P0060 Second Fault|es|P0060 Segunda Falla ";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0060
	}
}

COMMAND READ_P0060
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0060 }
	}
}

METHOD SET_PAR_NUMBER_0060
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 60;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0061
{
	LABEL "P0061 Current at 2nd Fault|es|P0061 Corriente 2 Falla";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "A";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0061
	}
}

COMMAND READ_P0061
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0061 }
	}
}

METHOD SET_PAR_NUMBER_0061
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 61;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0062
{
	LABEL "P0062 DC Link at 2nd Fault|es|P0062 Bus CC 2 Falla";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 2000;
	}
	CONSTANT_UNIT "V";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0062
	}
}

COMMAND READ_P0062
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0062 }
	}
}

METHOD SET_PAR_NUMBER_0062
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 62;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0063
{
	LABEL "P0063 Frequency 2nd Fault|es|P0063 Frecuencia 2 Falla";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0063
	}
}

COMMAND READ_P0063
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0063 }
	}
}

METHOD SET_PAR_NUMBER_0063
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 63;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0064
{
	LABEL "P0064 Temp. 2nd Fault |es|P0064 Temp. 2 Falla";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -20;
		MAX_VALUE 150;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0064
	}
}

COMMAND READ_P0064
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0064 }
	}
}

METHOD SET_PAR_NUMBER_0064
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 64;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0065
{
	LABEL "P0065 Log. State 2nd Fault |es|P0065 Estado Lg. 2 Falla";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0065
	}
}

COMMAND READ_P0065
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0065 }
	}
}

METHOD SET_PAR_NUMBER_0065
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 65;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0070
{
	LABEL "P0070 Third Fault|es|P0070 Tercera Falla ";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0070
	}
}

COMMAND READ_P0070
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0070 }
	}
}

METHOD SET_PAR_NUMBER_0070
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 70;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0071
{
	LABEL "P0071 Current at 3rd Fault|es|P0071 Corriente 3 Falla";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "A";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0071
	}
}

COMMAND READ_P0071
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0071 }
	}
}

METHOD SET_PAR_NUMBER_0071
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 71;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0072
{
	LABEL "P0072 DC Link 3rd Fault|es|P0072 Bus CC 3 Falla";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 2000;
	}
	CONSTANT_UNIT "V";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0072
	}
}

COMMAND READ_P0072
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0072 }
	}
}

METHOD SET_PAR_NUMBER_0072
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 72;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0073
{
	LABEL "P0073 Speed 3rd Fault|es|P0073 Velocidad 3 Falla";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0073
	}
}

COMMAND READ_P0073
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0073 }
	}
}

METHOD SET_PAR_NUMBER_0073
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 73;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0074
{
	LABEL "P0074 Temp. 3rd Fault |es|P0074 Temp. 3 Falla";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -20;
		MAX_VALUE 150;
	}
	CONSTANT_UNIT "C";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0074
	}
}

COMMAND READ_P0074
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0074 }
	}
}

METHOD SET_PAR_NUMBER_0074
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 74;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0075
{
	LABEL "P0075 Log. State 3rd Fault |es|P0075 Estado Lg. 3 Falla";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0075
	}
}

COMMAND READ_P0075
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0075 }
	}
}

METHOD SET_PAR_NUMBER_0075
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 75;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0100
{
	LABEL "P0100 Acceleration Time|es|P0100 Tiempo Aceleracin";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 10;
		MIN_VALUE 0.1;
		MAX_VALUE 999;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0100
	}
}

COMMAND READ_P0100
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0100 }
	}
}

METHOD SET_PAR_NUMBER_0100
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 100;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0100 LIKE READ_P0100
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 100, P0100 }
		REPLY { }
	}
}

VARIABLE P0101
{
	LABEL "P0101 Deceleration Time|es|P0101 Tiempo Desaceleracin";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 10;
		MIN_VALUE 0.1;
		MAX_VALUE 999;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0101
	}
}

COMMAND READ_P0101
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0101 }
	}
}

METHOD SET_PAR_NUMBER_0101
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 101;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0101 LIKE READ_P0101
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 101, P0101 }
		REPLY { }
	}
}

VARIABLE P0102
{
	LABEL "P0102 2nd Ramp Accel. Time|es|P0102 Tiempo Aceler. 2 Rampa";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 10;
		MIN_VALUE 0.1;
		MAX_VALUE 999;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0102
	}
}

COMMAND READ_P0102
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0102 }
	}
}

METHOD SET_PAR_NUMBER_0102
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 102;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0102 LIKE READ_P0102
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 102, P0102 }
		REPLY { }
	}
}

VARIABLE P0103
{
	LABEL "P0103 2nd Ramp Decel. Time|es|P0103 Tiempo Desacel. 2 Rampa";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 10;
		MIN_VALUE 0.1;
		MAX_VALUE 999;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0103
	}
}

COMMAND READ_P0103
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0103 }
	}
}

METHOD SET_PAR_NUMBER_0103
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 103;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0103 LIKE READ_P0103
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 103, P0103 }
		REPLY { }
	}
}

VARIABLE P0104
{
	LABEL "P0104 S Ramp|es|P0104 Rampa S ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0104
	}
}

COMMAND READ_P0104
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0104 }
	}
}

METHOD SET_PAR_NUMBER_0104
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 104;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0104 LIKE READ_P0104
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 104, P0104 }
		REPLY { }
	}
}

VARIABLE P0105
{
	LABEL "P0105 1st/2nd Ramp Sel.|es|P0105 Seleccin 1/2 Rampa ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "First Ramp|es|Primera Rampa" },
		{ 1, "Second Ramp|es|Segunda Rampa" },
		{ 2, "DIx|es|DIx" },
		{ 3, "Serial/USB|es|Serie/USB" },
		{ 4, "reserved|es|reservado" },
		{ 5, "CANop/DNet|es|CANop/DNet" },
		{ 6, "SoftPLC|es|SoftPLC" }
		DEFAULT_VALUE 3;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0105
	}
}

COMMAND READ_P0105
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0105 }
	}
}

METHOD SET_PAR_NUMBER_0105
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 105;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0105 LIKE READ_P0105
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 105, P0105 }
		REPLY { }
	}
}

VARIABLE P0106
{
	LABEL "P0106 3rd Ramp Accel. Time|es|P0106 Tiempo Aceler. 3 Rampa";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 5;
		MIN_VALUE 0.1;
		MAX_VALUE 999;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0106
	}
}

COMMAND READ_P0106
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0106 }
	}
}

METHOD SET_PAR_NUMBER_0106
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 106;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0106 LIKE READ_P0106
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 106, P0106 }
		REPLY { }
	}
}

VARIABLE P0120
{
	LABEL "P0120 Speed Ref. Backup|es|P0120 Backup Ref. Velocidad";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 0;
		MAX_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0120
	}
}

COMMAND READ_P0120
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0120 }
	}
}

METHOD SET_PAR_NUMBER_0120
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 120;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0120 LIKE READ_P0120
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 120, P0120 }
		REPLY { }
	}
}

VARIABLE P0121
{
	LABEL "P0121 HMI Reference|es|P0121 Referencia por la HMI";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 3;
		MIN_VALUE 0;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0121
	}
}

COMMAND READ_P0121
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0121 }
	}
}

METHOD SET_PAR_NUMBER_0121
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 121;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0121 LIKE READ_P0121
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 121, P0121 }
		REPLY { }
	}
}

VARIABLE P0122
{
	LABEL "P0122 JOG Reference |es|P0122 Referencia JOG";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 5;
		MIN_VALUE -500;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0122
	}
}

COMMAND READ_P0122
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0122 }
	}
}

METHOD SET_PAR_NUMBER_0122
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 122;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0122 LIKE READ_P0122
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 122, P0122 }
		REPLY { }
	}
}

VARIABLE P0124
{
	LABEL "P0124 Multispeed Ref. 1|es|P0124 Ref. 1 Multispeed";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 3;
		MIN_VALUE -500;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0124
	}
}

COMMAND READ_P0124
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0124 }
	}
}

METHOD SET_PAR_NUMBER_0124
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 124;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0124 LIKE READ_P0124
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 124, P0124 }
		REPLY { }
	}
}

VARIABLE P0125
{
	LABEL "P0125 Multispeed Ref. 2|es|P0125 Ref. 2 Multispeed";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 10;
		MIN_VALUE -500;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0125
	}
}

COMMAND READ_P0125
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0125 }
	}
}

METHOD SET_PAR_NUMBER_0125
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 125;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0125 LIKE READ_P0125
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 125, P0125 }
		REPLY { }
	}
}

VARIABLE P0126
{
	LABEL "P0126 Multispeed Ref. 3|es|P0126 Ref. 3 Multispeed";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 20;
		MIN_VALUE -500;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0126
	}
}

COMMAND READ_P0126
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0126 }
	}
}

METHOD SET_PAR_NUMBER_0126
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 126;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0126 LIKE READ_P0126
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 126, P0126 }
		REPLY { }
	}
}

VARIABLE P0127
{
	LABEL "P0127 Multispeed Ref. 4|es|P0127 Ref. 4 Multispeed";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 30;
		MIN_VALUE -500;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0127
	}
}

COMMAND READ_P0127
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0127 }
	}
}

METHOD SET_PAR_NUMBER_0127
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 127;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0127 LIKE READ_P0127
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 127, P0127 }
		REPLY { }
	}
}

VARIABLE P0128
{
	LABEL "P0128 Multispeed Ref. 5|es|P0128 Ref. 5 Multispeed";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 40;
		MIN_VALUE -500;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0128
	}
}

COMMAND READ_P0128
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0128 }
	}
}

METHOD SET_PAR_NUMBER_0128
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 128;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0128 LIKE READ_P0128
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 128, P0128 }
		REPLY { }
	}
}

VARIABLE P0129
{
	LABEL "P0129 Multispeed Ref. 6|es|P0129 Ref. 6 Multispeed";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 50;
		MIN_VALUE -500;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0129
	}
}

COMMAND READ_P0129
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0129 }
	}
}

METHOD SET_PAR_NUMBER_0129
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 129;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0129 LIKE READ_P0129
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 129, P0129 }
		REPLY { }
	}
}

VARIABLE P0130
{
	LABEL "P0130 Multispeed Ref. 7|es|P0130 Ref. 7 Multispeed";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 60;
		MIN_VALUE -500;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0130
	}
}

COMMAND READ_P0130
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0130 }
	}
}

METHOD SET_PAR_NUMBER_0130
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 130;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0130 LIKE READ_P0130
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 130, P0130 }
		REPLY { }
	}
}

VARIABLE P0131
{
	LABEL "P0131 Multispeed Ref. 8|es|P0131 Ref. 8 Multispeed";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 66;
		MIN_VALUE -500;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0131
	}
}

COMMAND READ_P0131
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0131 }
	}
}

METHOD SET_PAR_NUMBER_0131
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 131;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0131 LIKE READ_P0131
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 131, P0131 }
		REPLY { }
	}
}

VARIABLE P0133
{
	LABEL "P0133 Minimum Speed |es|P0133 Velocidad Mnima";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 3;
		MIN_VALUE 0;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0133
	}
}

COMMAND READ_P0133
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0133 }
	}
}

METHOD SET_PAR_NUMBER_0133
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 133;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0133 LIKE READ_P0133
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 133, P0133 }
		REPLY { }
	}
}

VARIABLE P0134
{
	LABEL "P0134 Maximum Speed |es|P0134 Velocidad Mxima";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 66;
		MIN_VALUE 0;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0134
	}
}

COMMAND READ_P0134
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0134 }
	}
}

METHOD SET_PAR_NUMBER_0134
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 134;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0134 LIKE READ_P0134
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 134, P0134 }
		REPLY { }
	}
}

VARIABLE P0135
{
	LABEL "P0135 Max. Output Current|es|P0135 Corriente Mx. Salida";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0135
	}
}

COMMAND READ_P0135
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0135 }
	}
}

METHOD SET_PAR_NUMBER_0135
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 135;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0135 LIKE READ_P0135
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 135, P0135 }
		REPLY { }
	}
}

VARIABLE P0136
{
	LABEL "P0136 Manual Torque Boost|es|P0136 Boost de Torque(Par) Manual";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0136
	}
}

COMMAND READ_P0136
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0136 }
	}
}

METHOD SET_PAR_NUMBER_0136
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 136;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0136 LIKE READ_P0136
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 136, P0136 }
		REPLY { }
	}
}

VARIABLE P0137
{
	LABEL "P0137 Autom. Torque Boost|es|P0137 Boost de Torque(Par) Automtico";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 30;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0137
	}
}

COMMAND READ_P0137
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0137 }
	}
}

METHOD SET_PAR_NUMBER_0137
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 137;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0137 LIKE READ_P0137
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 137, P0137 }
		REPLY { }
	}
}

VARIABLE P0138
{
	LABEL "P0138 Slip Compensation|es|P0138 Compensacin Deslizamiento";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE -10;
		MAX_VALUE 10;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0138
	}
}

COMMAND READ_P0138
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0138 }
	}
}

METHOD SET_PAR_NUMBER_0138
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 138;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0138 LIKE READ_P0138
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 138, P0138 }
		REPLY { }
	}
}

VARIABLE P0139
{
	LABEL "P0139 Output Current Filter|es|P0139 Filtro Corr. Salida";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 50;
		MIN_VALUE 0;
		MAX_VALUE 9999;
	}
	CONSTANT_UNIT "ms";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0139
	}
}

COMMAND READ_P0139
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0139 }
	}
}

METHOD SET_PAR_NUMBER_0139
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 139;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0139 LIKE READ_P0139
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 139, P0139 }
		REPLY { }
	}
}

VARIABLE P0140
{
	LABEL "P0140 Output Current Filter|es|P0140 Filtro Compens. Deslizamiento";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 500;
		MIN_VALUE 0;
		MAX_VALUE 9999;
	}
	CONSTANT_UNIT "ms";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0140
	}
}

COMMAND READ_P0140
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0140 }
	}
}

METHOD SET_PAR_NUMBER_0140
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 140;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0140 LIKE READ_P0140
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 140, P0140 }
		REPLY { }
	}
}

VARIABLE P0142
{
	LABEL "P0142 Max. Output Voltage|es|P0142 Tensin Salida Mxima";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 100;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0142
	}
}

COMMAND READ_P0142
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0142 }
	}
}

METHOD SET_PAR_NUMBER_0142
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 142;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0142 LIKE READ_P0142
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 142, P0142 }
		REPLY { }
	}
}

VARIABLE P0143
{
	LABEL "P0143 Interm. Output Voltage|es|P0143 Tensin Salida Intermediria";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 66.7;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0143
	}
}

COMMAND READ_P0143
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0143 }
	}
}

METHOD SET_PAR_NUMBER_0143
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 143;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0143 LIKE READ_P0143
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 143, P0143 }
		REPLY { }
	}
}

VARIABLE P0144
{
	LABEL "P0144 Low Output Voltage|es|P0144 Tensin Salida Baja";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 33.3;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0144
	}
}

COMMAND READ_P0144
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0144 }
	}
}

METHOD SET_PAR_NUMBER_0144
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 144;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0144 LIKE READ_P0144
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 144, P0144 }
		REPLY { }
	}
}

VARIABLE P0145
{
	LABEL "P0145 Field Weakening Speed|es|P0145 Vel. Inicio Enflaquec. Campo";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 60;
		MIN_VALUE 0;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0145
	}
}

COMMAND READ_P0145
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0145 }
	}
}

METHOD SET_PAR_NUMBER_0145
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 145;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0145 LIKE READ_P0145
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 145, P0145 }
		REPLY { }
	}
}

VARIABLE P0146
{
	LABEL "P0146 Intermediate Speed |es|P0146 Vel. Salida Intermediria";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 40;
		MIN_VALUE 0;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0146
	}
}

COMMAND READ_P0146
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0146 }
	}
}

METHOD SET_PAR_NUMBER_0146
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 146;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0146 LIKE READ_P0146
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 146, P0146 }
		REPLY { }
	}
}

VARIABLE P0147
{
	LABEL "P0147 Low Speed point |es|P0147 Vel. Salida Baja";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 20;
		MIN_VALUE 0;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0147
	}
}

COMMAND READ_P0147
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0147 }
	}
}

METHOD SET_PAR_NUMBER_0147
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 147;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0147 LIKE READ_P0147
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 147, P0147 }
		REPLY { }
	}
}

VARIABLE P0148
{
	LABEL "P0148 Switching Freq. Red. Temp.|es|P0148 Temperadura RedFs";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 100;
		MIN_VALUE 0;
		MAX_VALUE 150;
	}
	CONSTANT_UNIT "C";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0148
	}
}

COMMAND READ_P0148
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0148 }
	}
}

METHOD SET_PAR_NUMBER_0148
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 148;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0148 LIKE READ_P0148
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 148, P0148 }
		REPLY { }
	}
}

VARIABLE P0150
{
	LABEL "P0150 DC Regul. Type V/f|es|P0150 Tipo Regul. Ud V/f";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "hold_Ud and decel_LC|es|hold_Ud y desac_LC" },
		{ 1, "accel_Ud and decel_LC|es|acel_Ud y desac_LC " },
		{ 2, "hold_Ud and hold_LC|es|hold_Ud y hold_LC " },
		{ 3, "accel_Ud and hold_LC|es|acel_Ud y hold_LC " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0150
	}
}

COMMAND READ_P0150
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0150 }
	}
}

METHOD SET_PAR_NUMBER_0150
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 150;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0150 LIKE READ_P0150
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 150, P0150 }
		REPLY { }
	}
}

VARIABLE P0151
{
	LABEL "P0151 DC Regul. Level V/f|es|P0151 Nivel Regulador Ud V/f ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	CONSTANT_UNIT "V";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0151
	}
}

COMMAND READ_P0151
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0151 }
	}
}

METHOD SET_PAR_NUMBER_0151
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 151;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0151 LIKE READ_P0151
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 151, P0151 }
		REPLY { }
	}
}

VARIABLE P0152
{
	LABEL "P0152 DC Link Regul. P Gain|es|P0152 Ganancia Prop.Reg. Ud";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 1.5;
		MIN_VALUE 0;
		MAX_VALUE 9.99;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0152
	}
}

COMMAND READ_P0152
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0152 }
	}
}

METHOD SET_PAR_NUMBER_0152
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 152;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0152 LIKE READ_P0152
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 152, P0152 }
		REPLY { }
	}
}

VARIABLE P0153
{
	LABEL "P0153 Dyn. Braking Level |es|P0153 Nivel Frenado Reost.";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	CONSTANT_UNIT "V";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0153
	}
}

COMMAND READ_P0153
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0153 }
	}
}

METHOD SET_PAR_NUMBER_0153
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 153;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0153 LIKE READ_P0153
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 153, P0153 }
		REPLY { }
	}
}

VARIABLE P0156
{
	LABEL "P0156 Overl.Curr.100% Speed|es|P0156 Corriente Sobrecarga";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0156
	}
}

COMMAND READ_P0156
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0156 }
	}
}

METHOD SET_PAR_NUMBER_0156
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 156;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0156 LIKE READ_P0156
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 156, P0156 }
		REPLY { }
	}
}

VARIABLE P0157
{
	LABEL "P0157 Overl. Curr. 50% Speed|es|P0157 Corr. Sobrecarga 50%";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0157
	}
}

COMMAND READ_P0157
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0157 }
	}
}

METHOD SET_PAR_NUMBER_0157
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 157;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0157 LIKE READ_P0157
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 157, P0157 }
		REPLY { }
	}
}

VARIABLE P0158
{
	LABEL "P0158 Overl. Curr. 5% Speed|es|P0158 Corr. Sobrecarga 5%";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0158
	}
}

COMMAND READ_P0158
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0158 }
	}
}

METHOD SET_PAR_NUMBER_0158
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 158;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0158 LIKE READ_P0158
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 158, P0158 }
		REPLY { }
	}
}

VARIABLE P0178
{
	LABEL "P0178 Rated Flux|es|P0178 Flujo Nominal ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 100;
		MIN_VALUE 0;
		MAX_VALUE 150;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0178
	}
}

COMMAND READ_P0178
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0178 }
	}
}

METHOD SET_PAR_NUMBER_0178
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 178;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0178 LIKE READ_P0178
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 178, P0178 }
		REPLY { }
	}
}

VARIABLE P0200
{
	LABEL "P0200 Password|es|P0200 Contrasea ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 9999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0200
	}
}

COMMAND READ_P0200
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0200 }
	}
}

METHOD SET_PAR_NUMBER_0200
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 200;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0200 LIKE READ_P0200
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 200, P0200 }
		REPLY { }
	}
}

VARIABLE P0202
{
	LABEL "P0202 Type of Control|es|P0202 Tipo de Control ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "V/F|es|V/F" },
		{ 1, "Not Used|es|Sin Funcin " },
		{ 2, "Not Used|es|Sin Funcin " },
		{ 3, "Not Used|es|Sin Funcin " },
		{ 4, "Not Used|es|Sin Funcin " },
		{ 5, "VVW|es|VVW" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0202
	}
}

COMMAND READ_P0202
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0202 }
	}
}

METHOD SET_PAR_NUMBER_0202
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 202;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0202 LIKE READ_P0202
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 202, P0202 }
		REPLY { }
	}
}

VARIABLE P0203
{
	LABEL "P0203 Special Function Sel.|es|P0203 Sel. Funcin Especial";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "None|es|Ninguna " },
		{ 1, "PID via AI1|es|PID va AI1" },
		{ 2, "PID via AI3|es|PID va AI3" },
		{ 3, "PID via FI|es|PID va FI" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0203
	}
}

COMMAND READ_P0203
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0203 }
	}
}

METHOD SET_PAR_NUMBER_0203
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 203;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0203 LIKE READ_P0203
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 203, P0203 }
		REPLY { }
	}
}

VARIABLE P0204
{
	LABEL "P0204 Load/Save Parameters|es|P0204 Carga/Guarda Parm.";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used|es|Sin Funcin " },
		{ 1, "Not Used|es|Sin Funcin " },
		{ 2, "Reset P0045|es|Reset P0045" },
		{ 3, "Not Used|es|Sin Funcin " },
		{ 4, "Not Used|es|Sin Funcin " },
		{ 5, "Load 60Hz|es|Carga 60Hz" },
		{ 6, "Load 50Hz|es|Carga 50Hz" },
		{ 7, "Load User 1|es|Carga Usuario 1" },
		{ 8, "Load User 2|es|Carga Usuario 2 " },
		{ 9, "Save User 1|es|Guarda Usuario 1" },
		{ 10, "Save User 2|es|Guarda Usuario 2" },
		{ 11, "Load SoftPLC|es|Carga SoftPLC" },
		{ 12, "Reserved|es|Reservado" },
		{ 13, "Reserved|es|Reservado" },
		{ 14, "Reserved|es|Reservado" },
		{ 15, "Reserved|es|Reservado" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0204
	}
}

COMMAND READ_P0204
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0204 }
	}
}

METHOD SET_PAR_NUMBER_0204
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 204;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0204 LIKE READ_P0204
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 204, P0204 }
		REPLY { }
	}
}

VARIABLE P0205
{
	LABEL "P0205 Main Parameter Display|es|P0205 Parm. Display Princ. ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 2;
		MIN_VALUE 0;
		MAX_VALUE 1500;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0205
	}
}

COMMAND READ_P0205
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0205 }
	}
}

METHOD SET_PAR_NUMBER_0205
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 205;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0205 LIKE READ_P0205
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 205, P0205 }
		REPLY { }
	}
}

VARIABLE P0206
{
	LABEL "P0206 Aux. Parameter Display|es|P0206 Parm. Display Aux. ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 0;
		MAX_VALUE 1500;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0206
	}
}

COMMAND READ_P0206
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0206 }
	}
}

METHOD SET_PAR_NUMBER_0206
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 206;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0206 LIKE READ_P0206
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 206, P0206 }
		REPLY { }
	}
}

VARIABLE P0207
{
	LABEL "P0207 Parameter for bar|es|P0207 Parm. para Barra ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 3;
		MIN_VALUE 0;
		MAX_VALUE 1500;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0207
	}
}

COMMAND READ_P0207
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0207 }
	}
}

METHOD SET_PAR_NUMBER_0207
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 207;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0207 LIKE READ_P0207
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 207, P0207 }
		REPLY { }
	}
}

VARIABLE P0208
{
	LABEL "P0208 Ref. Scale Factor|es|P0208 Factor Escala Ref. ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 600;
		MIN_VALUE 1;
		MAX_VALUE 65535;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0208
	}
}

COMMAND READ_P0208
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0208 }
	}
}

METHOD SET_PAR_NUMBER_0208
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 208;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0208 LIKE READ_P0208
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 208, P0208 }
		REPLY { }
	}
}

VARIABLE P0209
{
	LABEL "P0209 Ref. Eng. Unit |es|P0209 Unidad Ing. Ref. ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "None|es|Sin unidad" },
		{ 1, "V|es|V" },
		{ 2, "A|es|A" },
		{ 3, "rpm|es|rpm" },
		{ 4, "s|es|s" },
		{ 5, "ms|es|ms" },
		{ 6, "N|es|N" },
		{ 7, "m|es|m" },
		{ 8, "Nm|es|Nm" },
		{ 9, "mA|es|mA" },
		{ 10, "%|es|%" },
		{ 11, "C|es|C" },
		{ 12, "CV|es|CV" },
		{ 13, "Hz|es|Hz" },
		{ 14, "HP|es|HP" },
		{ 15, "h|es|h" },
		{ 16, "W|es|W" },
		{ 17, "kW|es|kW" },
		{ 18, "kWh|es|kWh" },
		{ 19, "H|es|H" }
		DEFAULT_VALUE 13;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0209
	}
}

COMMAND READ_P0209
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0209 }
	}
}

METHOD SET_PAR_NUMBER_0209
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 209;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0209 LIKE READ_P0209
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 209, P0209 }
		REPLY { }
	}
}

VARIABLE P0210
{
	LABEL "P0210 Ref. Decimal Point |es|P0210 Punto Decimal Ref. ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "wxyz|es|wxyz" },
		{ 1, "wxy.z|es|wxy.z" },
		{ 2, "wx.yz|es|wx.yz" },
		{ 3, "w.xyz|es|w.xyz" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0210
	}
}

COMMAND READ_P0210
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0210 }
	}
}

METHOD SET_PAR_NUMBER_0210
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 210;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0210 LIKE READ_P0210
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 210, P0210 }
		REPLY { }
	}
}

VARIABLE P0213
{
	LABEL "P0213 Bar Scale Factor|es|P0213 Factor Escala Barra ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0213
	}
}

COMMAND READ_P0213
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0213 }
	}
}

METHOD SET_PAR_NUMBER_0213
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 213;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0213 LIKE READ_P0213
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 213, P0213 }
		REPLY { }
	}
}

VARIABLE P0216
{
	LABEL "P0216 HMI Backlight|es|P0216 Iluminacin Display HMI";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 0;
		MAX_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0216
	}
}

COMMAND READ_P0216
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0216 }
	}
}

METHOD SET_PAR_NUMBER_0216
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 216;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0216 LIKE READ_P0216
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 216, P0216 }
		REPLY { }
	}
}

VARIABLE P0217
{
	LABEL "P0217 Sleep Frequency|es|P0217 Frecuencia para reposo";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0217
	}
}

COMMAND READ_P0217
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0217 }
	}
}

METHOD SET_PAR_NUMBER_0217
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 217;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0217 LIKE READ_P0217
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 217, P0217 }
		REPLY { }
	}
}

VARIABLE P0218
{
	LABEL "P0218 Time to Sleep|es|P0218 Tiempo para reposo";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0218
	}
}

COMMAND READ_P0218
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0218 }
	}
}

METHOD SET_PAR_NUMBER_0218
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 218;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0218 LIKE READ_P0218
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 218, P0218 }
		REPLY { }
	}
}

VARIABLE P0220
{
	LABEL "P0220 LOC/REM Selection Src|es|P0220 Seleccin LOC/REM ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Always LOC|es|Siempre LOC" },
		{ 1, "Always REM|es|Siempre REM" },
		{ 2, "HMI Key (LOC)|es|Tecla HMI (LOC)" },
		{ 3, "HMI Key (REM)|es|Tecla HMMI (REM)" },
		{ 4, "DIx|es|DIx" },
		{ 5, "Serial/USB (LOC)|es|SerialUSB (LOC)" },
		{ 6, "Serial/USB (REM)|es|Serial/USB (REM) " },
		{ 7, "Not Used|es|Sin Funcin " },
		{ 8, "Not Used|es|Sin Funcin " },
		{ 9, "CANop/Dnet/PB(LOC)|es|CANop/DNet (LOC)" },
		{ 10, "CANop/Dnet/PB (REM)|es|CANop/DNet (REM)" },
		{ 11, "SoftPLC|es|SoftPLC" }
		DEFAULT_VALUE 4;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0220
	}
}

COMMAND READ_P0220
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0220 }
	}
}

METHOD SET_PAR_NUMBER_0220
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 220;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0220 LIKE READ_P0220
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 220, P0220 }
		REPLY { }
	}
}

VARIABLE P0221
{
	LABEL "P0221 LOC Reference Sel. |es|P0221 Selec. Referencia LOC";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Keypad|es|HMI" },
		{ 1, "AI1 |es|AI1 " },
		{ 2, "AI2 |es|AI2 " },
		{ 3, "AI3 |es|AI3 " },
		{ 4, "FI|es|FI" },
		{ 5, "Sum AIs > 0|es|Suma AIs > 0 " },
		{ 6, "Sum AIs |es|Suma AIs " },
		{ 7, "E.P.|es|E.P." },
		{ 8, "Multispeed|es|Multispeed" },
		{ 9, "Serial/USB|es|Serial/USB" },
		{ 10, "Not Used|es|Sin Funcin " },
		{ 11, "CANop/Dnet/PB|es|CANop/DNet" },
		{ 12, "SoftPLC|es|SoftPLC" },
		{ 13, "Not Used|es|Sin Funcin " },
		{ 14, "AI1 > 0 |es|AI1 > 0 " },
		{ 15, "AI2 > 0 |es|AI2 > 0 " },
		{ 16, "AI3 > 0 |es|AI3 > 0 " },
		{ 17, "FI > 0 |es|FI > 0 " },
		{ 18, "Knob|es|Knob" }
		DEFAULT_VALUE 18;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0221
	}
}

COMMAND READ_P0221
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0221 }
	}
}

METHOD SET_PAR_NUMBER_0221
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 221;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0221 LIKE READ_P0221
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 221, P0221 }
		REPLY { }
	}
}

VARIABLE P0222
{
	LABEL "P0222 REM Reference Sel. |es|P0222 Selec. Referencia REM";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Keypad|es|HMI" },
		{ 1, "AI1 |es|AI1 " },
		{ 2, "AI2 |es|AI2 " },
		{ 3, "AI3 |es|AI3 " },
		{ 4, "FI|es|FI" },
		{ 5, "Sum AIs > 0|es|Suma AIs > 0 " },
		{ 6, "Sum AIs |es|Suma AIs " },
		{ 7, "E.P.|es|E.P." },
		{ 8, "Multispeed|es|Multispeed" },
		{ 9, "Serial/USB|es|Serial/USB" },
		{ 10, "Not Used|es|Sin Funcin " },
		{ 11, "CANop/Dnet/PB|es|CANop/DNet" },
		{ 12, "SoftPLC|es|SoftPLC" },
		{ 13, "Not Used|es|Sin Funcin " },
		{ 14, "AI1 > 0 |es|AI1 > 0 " },
		{ 15, "AI2 > 0 |es|AI2 > 0 " },
		{ 16, "AI3 > 0 |es|AI3 > 0 " },
		{ 17, "FI > 0 |es|FI > 0 " },
		{ 18, "Knob|es|Knob" }
		DEFAULT_VALUE 9;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0222
	}
}

COMMAND READ_P0222
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0222 }
	}
}

METHOD SET_PAR_NUMBER_0222
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 222;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0222 LIKE READ_P0222
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 222, P0222 }
		REPLY { }
	}
}

VARIABLE P0223
{
	LABEL "P0223 LOC FWD/REV Selection|es|P0223 Seleccin Giro LOC";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Always FWD|es|Horario " },
		{ 1, "Always REV|es|Anti-Horario" },
		{ 2, "HMI Key (FWD)|es|Tecla HMI (H)" },
		{ 3, "HMI Key (REV)|es|Tecla HMI (AH) " },
		{ 4, "DIx |es|DIx " },
		{ 5, "Serial/USB (FWD)|es|Serial/USB (H) " },
		{ 6, "Serial/USB (REV)|es|Serial/USB (AH)" },
		{ 7, "Not Used|es|Sin Funcin " },
		{ 8, "Not Used|es|Sin Funcin " },
		{ 9, "CANop/Dnet/PB (FWD)|es|CANop/DNet (H)" },
		{ 10, "CANop/Dnet/PB (REV)|es|CANop/DNet(AH)" },
		{ 11, "Not Used|es|Sin Funcin " },
		{ 12, "SoftPLC|es|SoftPLC" }
		DEFAULT_VALUE 4;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0223
	}
}

COMMAND READ_P0223
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0223 }
	}
}

METHOD SET_PAR_NUMBER_0223
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 223;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0223 LIKE READ_P0223
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 223, P0223 }
		REPLY { }
	}
}

VARIABLE P0224
{
	LABEL "P0224 LOC Run/Stop Sel.|es|P0224 Selec. Gira/Para LOC";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "HMI Keys|es|Teclas HMI" },
		{ 1, "DIx |es|DIx " },
		{ 2, "Serial/USB|es|Serial/USB" },
		{ 3, "Not Used|es|Sin Funcin " },
		{ 4, "CANop/Dnet/PB|es|CANop/DNet" },
		{ 5, "SoftPLC|es|SoftPLC" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0224
	}
}

COMMAND READ_P0224
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0224 }
	}
}

METHOD SET_PAR_NUMBER_0224
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 224;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0224 LIKE READ_P0224
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 224, P0224 }
		REPLY { }
	}
}

VARIABLE P0225
{
	LABEL "P0225 LOC JOG Selection|es|P0225 Seleccin JOG LOC";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disable |es|Inactivo" },
		{ 1, "HMI Key|es|Tecla HMI" },
		{ 2, "DIx |es|DIx " },
		{ 3, "Serial/USB|es|Serial/USB" },
		{ 4, "Not Used|es|Sin Funcin " },
		{ 5, "CANop/Dnet/PB|es|CANop/DNet" },
		{ 6, "SoftPLC|es|SoftPLC" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0225
	}
}

COMMAND READ_P0225
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0225 }
	}
}

METHOD SET_PAR_NUMBER_0225
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 225;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0225 LIKE READ_P0225
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 225, P0225 }
		REPLY { }
	}
}

VARIABLE P0226
{
	LABEL "P0226 REM FWD/REV Selection|es|P0226 Seleccin Giro REM";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Always FWD|es|Horario " },
		{ 1, "Always REV|es|Anti-Horario" },
		{ 2, "HMI Key (FWD)|es|Tecla HMI (H)" },
		{ 3, "HMI Key (REV)|es|Tecla HMI (AH)" },
		{ 4, "DIx |es|DIx " },
		{ 5, "Serial/USB (FWD)|es|Serial/USB (H) " },
		{ 6, "Serial/USB (REV)|es|Serial/USB (AH)" },
		{ 7, "Not Used|es|Sin Funcin " },
		{ 8, "Not Used|es|Sin Funcin " },
		{ 9, "CANop/Dnet/PB (FWD)|es|CANop/DNet (H)" },
		{ 10, "CANop/Dnet/PB (REV)|es|CANop/DNet(AH)" },
		{ 11, "Not Used|es|Sin Funcin " },
		{ 12, "SoftPLC|es|SoftPLC" }
		DEFAULT_VALUE 5;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0226
	}
}

COMMAND READ_P0226
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0226 }
	}
}

METHOD SET_PAR_NUMBER_0226
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 226;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0226 LIKE READ_P0226
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 226, P0226 }
		REPLY { }
	}
}

VARIABLE P0227
{
	LABEL "P0227 REM Run/Stop Sel.|es|P0227 Selec. Gira/Para REM";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "HMI Key|es|Tecla HMI" },
		{ 1, "DIx |es|DIx " },
		{ 2, "Serial/USB|es|Serial/USB" },
		{ 3, "Not Used|es|Sin Funcin " },
		{ 4, "CANop/Dnet/PB|es|CANop/DNet" },
		{ 5, "SoftPLC|es|SoftPLC" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0227
	}
}

COMMAND READ_P0227
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0227 }
	}
}

METHOD SET_PAR_NUMBER_0227
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 227;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0227 LIKE READ_P0227
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 227, P0227 }
		REPLY { }
	}
}

VARIABLE P0228
{
	LABEL "P0228 REM JOG Selection|es|P0228 Seleccin JOG REM";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disable |es|Inactivo" },
		{ 1, "HMI Key|es|Tecla HMI" },
		{ 2, "DIx |es|DIx " },
		{ 3, "Serial/USB|es|Serial/USB" },
		{ 4, "Not Used|es|Sin Funcin " },
		{ 5, "CANop/Dnet/PB|es|CANop/DNet" },
		{ 6, "SoftPLC|es|SoftPLC" }
		DEFAULT_VALUE 3;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0228
	}
}

COMMAND READ_P0228
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0228 }
	}
}

METHOD SET_PAR_NUMBER_0228
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 228;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0228 LIKE READ_P0228
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 228, P0228 }
		REPLY { }
	}
}

VARIABLE P0229
{
	LABEL "P0229 Stop Mode Selection|es|P0229 Seleccin de Parada";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "By Ramp|es|Por Rampa" },
		{ 1, "Coast to Stop|es|Por Inercia" },
		{ 2, "Quick Stop|es|Parada Rpida" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0229
	}
}

COMMAND READ_P0229
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0229 }
	}
}

METHOD SET_PAR_NUMBER_0229
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 229;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0229 LIKE READ_P0229
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 229, P0229 }
		REPLY { }
	}
}

VARIABLE P0230
{
	LABEL "P0230 Dead Zone (AIs)|es|P0230 Zona Muerta ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off |es|Inactiva" },
		{ 1, "On|es|Activa" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0230
	}
}

COMMAND READ_P0230
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0230 }
	}
}

METHOD SET_PAR_NUMBER_0230
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 230;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0230 LIKE READ_P0230
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 230, P0230 }
		REPLY { }
	}
}

VARIABLE P0231
{
	LABEL "P0231 AI1 Signal Function|es|P0231 Funcin Seal AI1";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Speed Ref.|es|Ref. Veloc." },
		{ 1, "Not Used|es|Sin Funcin " },
		{ 2, "Not Used|es|Sin Funcin " },
		{ 3, "Not Used|es|Sin Funcin " },
		{ 4, "PTC|es|PTC" },
		{ 5, "Not Used|es|Sin Funcin " },
		{ 6, "Not Used|es|Sin Funcin " },
		{ 7, "PLC Use |es|SoftPLC " },
		{ 8, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 9, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 10, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 11, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 12, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 13, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 14, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 15, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0231
	}
}

COMMAND READ_P0231
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0231 }
	}
}

METHOD SET_PAR_NUMBER_0231
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 231;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0231 LIKE READ_P0231
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 231, P0231 }
		REPLY { }
	}
}

VARIABLE P0232
{
	LABEL "P0232 AI1 Gain|es|P0232 Ganancia Entrada AI1 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 1;
		MIN_VALUE 0;
		MAX_VALUE 9.999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0232
	}
}

COMMAND READ_P0232
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0232 }
	}
}

METHOD SET_PAR_NUMBER_0232
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 232;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0232 LIKE READ_P0232
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 232, P0232 }
		REPLY { }
	}
}

VARIABLE P0233
{
	LABEL "P0233 AI1 Signal Type |es|P0233 Seal Entrada AI1";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "0 to 10V/20mA|es|0 a 10V/20mA" },
		{ 1, "4 to 20 mA |es|4 a 20 mA " },
		{ 2, "10V/20mA to 0|es|10V/20mA a 0" },
		{ 3, "20 to 4 mA |es|20 a 4 mA " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0233
	}
}

COMMAND READ_P0233
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0233 }
	}
}

METHOD SET_PAR_NUMBER_0233
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 233;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0233 LIKE READ_P0233
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 233, P0233 }
		REPLY { }
	}
}

VARIABLE P0234
{
	LABEL "P0234 AI1 Offset|es|P0234 Offset Entrada AI1 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE -100;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0234
	}
}

COMMAND READ_P0234
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0234 }
	}
}

METHOD SET_PAR_NUMBER_0234
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 234;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0234 LIKE READ_P0234
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 234, P0234 }
		REPLY { }
	}
}

VARIABLE P0235
{
	LABEL "P0235 AI1 Filter|es|P0235 Filtro Entrada AI1";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 16;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0235
	}
}

COMMAND READ_P0235
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0235 }
	}
}

METHOD SET_PAR_NUMBER_0235
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 235;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0235 LIKE READ_P0235
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 235, P0235 }
		REPLY { }
	}
}

VARIABLE P0236
{
	LABEL "P0236 AI2 Signal Function|es|P0236 Funcin Seal AI2";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Speed Ref.|es|Ref. Veloc." },
		{ 1, "Not Used|es|Sin Funcin " },
		{ 2, "Not Used|es|Sin Funcin " },
		{ 3, "Not Used|es|Sin Funcin " },
		{ 4, "PTC|es|PTC" },
		{ 5, "Not Used|es|Sin Funcin " },
		{ 6, "Not Used|es|Sin Funcin " },
		{ 7, "PLC Use |es|SoftPLC " },
		{ 8, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 9, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 10, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 11, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 12, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 13, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 14, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 15, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0236
	}
}

COMMAND READ_P0236
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0236 }
	}
}

METHOD SET_PAR_NUMBER_0236
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 236;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0236 LIKE READ_P0236
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 236, P0236 }
		REPLY { }
	}
}

VARIABLE P0237
{
	LABEL "P0237 AI2 Gain|es|P0237 Ganancia Entrada AI2 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 1;
		MIN_VALUE 0;
		MAX_VALUE 9.999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0237
	}
}

COMMAND READ_P0237
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0237 }
	}
}

METHOD SET_PAR_NUMBER_0237
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 237;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0237 LIKE READ_P0237
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 237, P0237 }
		REPLY { }
	}
}

VARIABLE P0238
{
	LABEL "P0238 AI2 Signal Type |es|P0238 Seal Entrada AI2";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "0 to 10V/20mA|es|0 a 10V/20mA" },
		{ 1, "4 to 20 mA |es|4 a 20 mA " },
		{ 2, "10V/20mA to 0|es|10V/20mA a 0" },
		{ 3, "20 to 4 mA |es|20 a 4 mA " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0238
	}
}

COMMAND READ_P0238
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0238 }
	}
}

METHOD SET_PAR_NUMBER_0238
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 238;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0238 LIKE READ_P0238
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 238, P0238 }
		REPLY { }
	}
}

VARIABLE P0239
{
	LABEL "P0239 AI2 Offset|es|P0239 Offset Entrada AI2 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE -100;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0239
	}
}

COMMAND READ_P0239
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0239 }
	}
}

METHOD SET_PAR_NUMBER_0239
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 239;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0239 LIKE READ_P0239
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 239, P0239 }
		REPLY { }
	}
}

VARIABLE P0240
{
	LABEL "P0240 AI2 Filter|es|P0240 Filtro Entrada AI2";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 16;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0240
	}
}

COMMAND READ_P0240
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0240 }
	}
}

METHOD SET_PAR_NUMBER_0240
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 240;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0240 LIKE READ_P0240
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 240, P0240 }
		REPLY { }
	}
}

VARIABLE P0241
{
	LABEL "P0241 AI1 Signal Function|es|P0241 Funcin Seal AI1";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Speed Ref.|es|Ref. Veloc." },
		{ 1, "Not Used|es|Sin Funcin " },
		{ 2, "Not Used|es|Sin Funcin " },
		{ 3, "Not Used|es|Sin Funcin " },
		{ 4, "PTC|es|PTC" },
		{ 5, "Not Used|es|Sin Funcin " },
		{ 6, "Not Used|es|Sin Funcin " },
		{ 7, "PLC Use |es|SoftPLC " },
		{ 8, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 9, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 10, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 11, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 12, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 13, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 14, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 15, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0241
	}
}

COMMAND READ_P0241
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0241 }
	}
}

METHOD SET_PAR_NUMBER_0241
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 241;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0241 LIKE READ_P0241
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 241, P0241 }
		REPLY { }
	}
}

VARIABLE P0242
{
	LABEL "P0242 AI3 Gain|es|P0242 Ganancia Entrada AI3 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 1;
		MIN_VALUE 0;
		MAX_VALUE 9.999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0242
	}
}

COMMAND READ_P0242
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0242 }
	}
}

METHOD SET_PAR_NUMBER_0242
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 242;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0242 LIKE READ_P0242
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 242, P0242 }
		REPLY { }
	}
}

VARIABLE P0243
{
	LABEL "P0243 AI3 Signal Type |es|P0243 Seal Entrada AI3";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "0 to 10V/20mA|es|0 a 10V/20mA" },
		{ 1, "4 to 20 mA |es|4 a 20 mA " },
		{ 2, "10V/20mA to 0|es|10V/20mA a 0" },
		{ 3, "20 to 4 mA |es|20 a 4 mA " },
		{ 4, "-10 a +10V |es|-10 a +10V " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0243
	}
}

COMMAND READ_P0243
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0243 }
	}
}

METHOD SET_PAR_NUMBER_0243
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 243;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0243 LIKE READ_P0243
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 243, P0243 }
		REPLY { }
	}
}

VARIABLE P0244
{
	LABEL "P0244 AI3 Offset|es|P0244 Offset Entrada AI3 ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE -100;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0244
	}
}

COMMAND READ_P0244
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0244 }
	}
}

METHOD SET_PAR_NUMBER_0244
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 244;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0244 LIKE READ_P0244
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 244, P0244 }
		REPLY { }
	}
}

VARIABLE P0245
{
	LABEL "P0245 AI3 Filter|es|P0245 Filtro Entrada AI3";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 16;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0245
	}
}

COMMAND READ_P0245
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0245 }
	}
}

METHOD SET_PAR_NUMBER_0245
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 245;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0245 LIKE READ_P0245
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 245, P0245 }
		REPLY { }
	}
}

VARIABLE P0246
{
	LABEL "P0246 Freq. Input FI|es|P0246 Entrada em Frec. FI";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off |es|Inactiva" },
		{ 1, "On|es|Activa" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0246
	}
}

COMMAND READ_P0246
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0246 }
	}
}

METHOD SET_PAR_NUMBER_0246
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 246;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0246 LIKE READ_P0246
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 246, P0246 }
		REPLY { }
	}
}

VARIABLE P0247
{
	LABEL "P0247 FI Gain|es|P0247 Ganancia Entrada FI ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 1;
		MIN_VALUE 0;
		MAX_VALUE 9.999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0247
	}
}

COMMAND READ_P0247
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0247 }
	}
}

METHOD SET_PAR_NUMBER_0247
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 247;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0247 LIKE READ_P0247
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 247, P0247 }
		REPLY { }
	}
}

VARIABLE P0248
{
	LABEL "P0248 Min. FI|es|P0248 Entrada FI Mnima ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 10;
		MIN_VALUE 10;
		MAX_VALUE 20000;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0248
	}
}

COMMAND READ_P0248
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0248 }
	}
}

METHOD SET_PAR_NUMBER_0248
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 248;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0248 LIKE READ_P0248
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 248, P0248 }
		REPLY { }
	}
}

VARIABLE P0249
{
	LABEL "P0249 FI Offset|es|P0249 Offset Entrada FI ";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE -100;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0249
	}
}

COMMAND READ_P0249
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0249 }
	}
}

METHOD SET_PAR_NUMBER_0249
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 249;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0249 LIKE READ_P0249
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 249, P0249 }
		REPLY { }
	}
}

VARIABLE P0250
{
	LABEL "P0250 Max. FI|es|P0250 Entrada FI Mxima ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 10000;
		MIN_VALUE 10;
		MAX_VALUE 20000;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0250
	}
}

COMMAND READ_P0250
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0250 }
	}
}

METHOD SET_PAR_NUMBER_0250
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 250;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0250 LIKE READ_P0250
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 250, P0250 }
		REPLY { }
	}
}

VARIABLE P0251
{
	LABEL "P0251 AO1 Function|es|P0251 Funcin Salida AO1";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Speed Ref.|es|Ref. Velocidad" },
		{ 1, "Not Used|es|Sin Funcin " },
		{ 2, "Real Speed|es|Velocidad Real" },
		{ 3, "Not Used|es|Sin Funcin " },
		{ 4, "Not Used|es|Sin Funcin " },
		{ 5, "Output Current|es|Corr. Salida" },
		{ 6, "Process Var.|es|Var. Proceso" },
		{ 7, "Active Current|es|Corr. Activa" },
		{ 8, "Not Used|es|Sin Funcin " },
		{ 9, "PID Set point|es|Setpoint PID" },
		{ 10, "Not Used|es|Sin Funcin " },
		{ 11, "Motor Torque|es|Torque(Par) Motor " },
		{ 12, "SoftPLC|es|SoftPLC" },
		{ 13, "Not Used|es|Sin Funcin " },
		{ 14, "Not Used|es|Sin Funcin " },
		{ 15, "Not Used|es|Sin Funcin " },
		{ 16, "Motor Ixt|es|Ixt Motor" },
		{ 17, "Not Used|es|Sin Funcin " },
		{ 18, "P0696 Value|es|Contenido P0696" },
		{ 19, "P0697 Value|es|Contenido P0697" },
		{ 20, "P0698 Value|es|Contenido P0698" },
		{ 21, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 22, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 23, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 24, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 25, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 26, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 27, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 28, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0251
	}
}

COMMAND READ_P0251
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0251 }
	}
}

METHOD SET_PAR_NUMBER_0251
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 251;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0251 LIKE READ_P0251
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 251, P0251 }
		REPLY { }
	}
}

VARIABLE P0252
{
	LABEL "P0252 AO1 Gain|es|P0252 Ganancia Salida AO1";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 1;
		MIN_VALUE 0;
		MAX_VALUE 9.999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0252
	}
}

COMMAND READ_P0252
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0252 }
	}
}

METHOD SET_PAR_NUMBER_0252
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 252;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0252 LIKE READ_P0252
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 252, P0252 }
		REPLY { }
	}
}

VARIABLE P0253
{
	LABEL "P0253 AO1 Signal Type |es|P0253 Seal Salida AO1";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "0 to 10V|es|0 a 10V" },
		{ 1, "0 to 20 mA |es|0 a 20 mA " },
		{ 2, "4 to 20 mA |es|4 a 20 mA " },
		{ 3, "10V to 0|es|10V a 0" },
		{ 4, "20mA to 0|es|20mA a 0" },
		{ 5, "20 to 4 mA |es|20 a 4 mA " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0253
	}
}

COMMAND READ_P0253
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0253 }
	}
}

METHOD SET_PAR_NUMBER_0253
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 253;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0253 LIKE READ_P0253
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 253, P0253 }
		REPLY { }
	}
}

VARIABLE P0254
{
	LABEL "P0254 AO2 Function|es|P0254 Funcin Salida AO2";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Speed Ref.|es|Ref. Velocidad" },
		{ 1, "Not Used|es|Sin Funcin " },
		{ 2, "Real Speed|es|Velocidad Real" },
		{ 3, "Not Used|es|Sin Funcin " },
		{ 4, "Not Used|es|Sin Funcin " },
		{ 5, "Output Current|es|Corr. Salida" },
		{ 6, "Process Var.|es|Var. Proceso" },
		{ 7, "Active Current|es|Corr. Activa" },
		{ 8, "Not Used|es|Sin Funcin " },
		{ 9, "PID Set point|es|Setpoint PID" },
		{ 10, "Not Used|es|Sin Funcin " },
		{ 11, "Motor Torque|es|Torque(Par) Motor " },
		{ 12, "SoftPLC|es|SoftPLC" },
		{ 13, "Not Used|es|Sin Funcin " },
		{ 14, "Not Used|es|Sin Funcin " },
		{ 15, "Not Used|es|Sin Funcin " },
		{ 16, "Motor Ixt|es|Ixt Motor" },
		{ 17, "Not Used|es|Sin Funcin " },
		{ 18, "P0696 Value|es|Contenido P0696" },
		{ 19, "P0697 Value|es|Contenido P0697" },
		{ 20, "P0698 Value|es|Contenido P0698" },
		{ 21, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 22, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 23, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 24, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 25, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 26, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 27, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 28, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 5;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0254
	}
}

COMMAND READ_P0254
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0254 }
	}
}

METHOD SET_PAR_NUMBER_0254
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 254;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0254 LIKE READ_P0254
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 254, P0254 }
		REPLY { }
	}
}

VARIABLE P0255
{
	LABEL "P0255 AO2 Gain|es|P0255 Ganancia Salida AO2";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 1;
		MIN_VALUE 0;
		MAX_VALUE 9.999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0255
	}
}

COMMAND READ_P0255
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0255 }
	}
}

METHOD SET_PAR_NUMBER_0255
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 255;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0255 LIKE READ_P0255
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 0, 255, P0255 }
		REPLY { }
	}
}

VARIABLE P0256
{
	LABEL "P0256 AO2 Signal Type |es|P0256 Seal Salida AO2";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "0 to 10V|es|0 a 10V" },
		{ 1, "0 to 20 mA |es|0 a 20 mA " },
		{ 2, "4 to 20 mA |es|4 a 20 mA " },
		{ 3, "10V to 0|es|10V a 0" },
		{ 4, "20mA to 0|es|20mA a 0" },
		{ 5, "20 to 4 mA |es|20 a 4 mA " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0256
	}
}

COMMAND READ_P0256
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0256 }
	}
}

METHOD SET_PAR_NUMBER_0256
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 256;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0256 LIKE READ_P0256
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 0, P0256 }
		REPLY { }
	}
}

VARIABLE P0257
{
	LABEL "P0257 FO Function|es|P0257 Funcin Salida FO ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Speed Ref.|es|Ref. Velocidad" },
		{ 1, "Not Used|es|Sin Funcin " },
		{ 2, "Real Speed|es|Velocidad Real" },
		{ 3, "Not Used|es|Sin Funcin " },
		{ 4, "Not Used|es|Sin Funcin " },
		{ 5, "Output Current|es|Corr. Salida" },
		{ 6, "Process Var.|es|Var. Proceso" },
		{ 7, "Active Current|es|Corr. Activa" },
		{ 8, "Not Used|es|Sin Funcin " },
		{ 9, "PID Set point|es|Setpoint PID" },
		{ 10, "Not Used|es|Sin Funcin " },
		{ 11, "Motor Torque|es|Torque(Par) Motor " },
		{ 12, "SoftPLC|es|SoftPLC" },
		{ 13, "Not Used|es|Sin Funcin " },
		{ 14, "Not Used|es|Sin Funcin " },
		{ 15, "Disable FO|es|Deshabilita FO" },
		{ 16, "Motor Ixt|es|Ixt Motor" },
		{ 17, "Not Used|es|Sin Funcin " },
		{ 18, "P0696 Value|es|Contenido P0696" },
		{ 19, "P0697 Value|es|Contenido P0697" },
		{ 20, "P0698 Value|es|Contenido P0698" },
		{ 21, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 22, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 23, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 24, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 25, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 26, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 27, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 28, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 15;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0257
	}
}

COMMAND READ_P0257
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0257 }
	}
}

METHOD SET_PAR_NUMBER_0257
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 257;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0257 LIKE READ_P0257
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 1, P0257 }
		REPLY { }
	}
}

VARIABLE P0258
{
	LABEL "P0258 FO Gain|es|P0258 Ganancia Salida FO";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 1;
		MIN_VALUE 0;
		MAX_VALUE 9.999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0258
	}
}

COMMAND READ_P0258
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0258 }
	}
}

METHOD SET_PAR_NUMBER_0258
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 258;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0258 LIKE READ_P0258
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 2, P0258 }
		REPLY { }
	}
}

VARIABLE P0259
{
	LABEL "P0259 Min. FO|es|P0259 Salida FO Mnima ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 10;
		MIN_VALUE 10;
		MAX_VALUE 20000;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0259
	}
}

COMMAND READ_P0259
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0259 }
	}
}

METHOD SET_PAR_NUMBER_0259
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 259;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0259 LIKE READ_P0259
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 3, P0259 }
		REPLY { }
	}
}

VARIABLE P0260
{
	LABEL "P0260 Max. FO|es|P0260 Salida FO Mxima ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 10000;
		MIN_VALUE 10;
		MAX_VALUE 20000;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0260
	}
}

COMMAND READ_P0260
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0260 }
	}
}

METHOD SET_PAR_NUMBER_0260
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 260;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0260 LIKE READ_P0260
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 4, P0260 }
		REPLY { }
	}
}

VARIABLE P0263
{
	LABEL "P0263 DI1 Function|es|P0263 Funcin Entrada DI1";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used|es|Sin Funcin " },
		{ 1, "Run/Stop|es|Gira/Para " },
		{ 2, "General Enable|es|Hab. General" },
		{ 3, "Quick Stop|es|Parada Rpida" },
		{ 4, "FWD Run |es|Avance" },
		{ 5, "REV Run |es|Retroceso " },
		{ 6, "Start |es|Start " },
		{ 7, "Stop|es|Stop" },
		{ 8, "FWD/REV |es|Sentido Giro Horario " },
		{ 9, "LOC/REM |es|LOC/REM " },
		{ 10, "JOG |es|JOG " },
		{ 11, "Increase EP|es|Acelera EP" },
		{ 12, "Decrease EP|es|Desacelera EP" },
		{ 13, "Multispeed |es|Multispeed " },
		{ 14, "2nd Ramp|es|2 Rampa" },
		{ 15, "Not Used|es|Sin Funcin " },
		{ 16, "Not Used|es|Sin Funcin " },
		{ 17, "Not Used|es|Sin Funcin " },
		{ 18, "No Ext. Alarm|es|Sin Alarma Ext" },
		{ 19, "No Ext. Fault|es|Sin Falla Ext." },
		{ 20, "Reset|es|Reset " },
		{ 21, "SoftPLC|es|SoftPLC" },
		{ 22, "Manual/Auto PID|es|Manual/Autom. PID" },
		{ 23, "Not Used|es|Sin Funcin " },
		{ 24, "Disable Flying Start|es|Deshabilita FlyStart" },
		{ 25, "Not Used|es|Sin Funcin " },
		{ 26, "Program. Off|es|Bloquea Programa" },
		{ 27, "Load User 1|es|Carga User 1" },
		{ 28, "Load User 2|es|Carga User 2" },
		{ 29, "PTC|es|PTC" },
		{ 30, "Not Used|es|Sin Funcin " },
		{ 31, "Not Used|es|Sin Funcin " },
		{ 32, "2nd ramp Multispeed|es|Multispeed 2 rampa" },
		{ 33, "2nd ramp Increase EP|es|Acelera EP 2 rampa" },
		{ 34, "2nd ramp Decrease EP|es|Desacelera EP 2 rampa" },
		{ 35, "2nd ramp FWD Run |es|Avance 2 rampa " },
		{ 36, "2nd ramp REV Run |es|Retroceso 2 rampa" },
		{ 37, "Start / Inc. EP|es|Comenza / Ac. EP" },
		{ 38, "Dec. EP / Stop|es|De. EP / Para" },
		{ 39, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 40, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 41, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 42, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 43, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 44, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 45, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 46, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0263
	}
}

COMMAND READ_P0263
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0263 }
	}
}

METHOD SET_PAR_NUMBER_0263
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 263;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0263 LIKE READ_P0263
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 7, P0263 }
		REPLY { }
	}
}

VARIABLE P0264
{
	LABEL "P0264 DI2 Function|es|P0264 Funcin Entrada DI2";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used|es|Sin Funcin " },
		{ 1, "Run/Stop|es|Gira/Para " },
		{ 2, "General Enable|es|Hab. General" },
		{ 3, "Quick Stop|es|Parada Rpida" },
		{ 4, "FWD Run |es|Avance" },
		{ 5, "REV Run |es|Retroceso " },
		{ 6, "Start |es|Start " },
		{ 7, "Stop|es|Stop" },
		{ 8, "FWD/REV |es|Sentido Giro Horario " },
		{ 9, "LOC/REM |es|LOC/REM " },
		{ 10, "JOG |es|JOG " },
		{ 11, "Increase EP|es|Acelera EP" },
		{ 12, "Decrease EP|es|Desacelera EP" },
		{ 13, "Multispeed |es|Multispeed " },
		{ 14, "2nd Ramp|es|2 Rampa" },
		{ 15, "Not Used|es|Sin Funcin " },
		{ 16, "Not Used|es|Sin Funcin " },
		{ 17, "Not Used|es|Sin Funcin " },
		{ 18, "No Ext. Alarm|es|Sin Alarma Ext" },
		{ 19, "No Ext. Fault|es|Sin Falla Ext." },
		{ 20, "Reset|es|Reset " },
		{ 21, "SoftPLC|es|SoftPLC" },
		{ 22, "Manual/Auto PID|es|Manual/Autom. PID" },
		{ 23, "Not Used|es|Sin Funcin " },
		{ 24, "Disable Flying Start|es|Deshabilita FlyStart" },
		{ 25, "Not Used|es|Sin Funcin " },
		{ 26, "Program. Off|es|Bloquea Programa" },
		{ 27, "Load User 1|es|Carga User 1" },
		{ 28, "Load User 2|es|Carga User 2" },
		{ 29, "PTC|es|PTC" },
		{ 30, "Not Used|es|Sin Funcin " },
		{ 31, "Not Used|es|Sin Funcin " },
		{ 32, "2nd ramp Multispeed|es|Multispeed 2 rampa" },
		{ 33, "2nd ramp Increase EP|es|Acelera EP 2 rampa" },
		{ 34, "2nd ramp Decrease EP|es|Desacelera EP 2 rampa" },
		{ 35, "2nd ramp FWD Run |es|Avance 2 rampa " },
		{ 36, "2nd ramp REV Run |es|Retroceso 2 rampa" },
		{ 37, "Start / Inc. EP|es|Comenza / Ac. EP" },
		{ 38, "Dec. EP / Stop|es|De. EP / Para" },
		{ 39, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 40, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 41, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 42, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 43, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 44, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 45, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 46, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 8;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0264
	}
}

COMMAND READ_P0264
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0264 }
	}
}

METHOD SET_PAR_NUMBER_0264
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 264;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0264 LIKE READ_P0264
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 8, P0264 }
		REPLY { }
	}
}

VARIABLE P0265
{
	LABEL "P0265 DI3 Function|es|P0265 Funcin Entrada DI3";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used|es|Sin Funcin " },
		{ 1, "Run/Stop|es|Gira/Para " },
		{ 2, "General Enable|es|Hab. General" },
		{ 3, "Quick Stop|es|Parada Rpida" },
		{ 4, "FWD Run |es|Avance" },
		{ 5, "REV Run |es|Retroceso " },
		{ 6, "Start |es|Start " },
		{ 7, "Stop|es|Stop" },
		{ 8, "FWD/REV |es|Sentido Giro Horario " },
		{ 9, "LOC/REM |es|LOC/REM " },
		{ 10, "JOG |es|JOG " },
		{ 11, "Increase EP|es|Acelera EP" },
		{ 12, "Decrease EP|es|Desacelera EP" },
		{ 13, "Multispeed |es|Multispeed " },
		{ 14, "2nd Ramp|es|2 Rampa" },
		{ 15, "Not Used|es|Sin Funcin " },
		{ 16, "Not Used|es|Sin Funcin " },
		{ 17, "Not Used|es|Sin Funcin " },
		{ 18, "No Ext. Alarm|es|Sin Alarma Ext" },
		{ 19, "No Ext. Fault|es|Sin Falla Ext." },
		{ 20, "Reset|es|Reset " },
		{ 21, "SoftPLC|es|SoftPLC" },
		{ 22, "Manual/Auto PID|es|Manual/Autom. PID" },
		{ 23, "Not Used|es|Sin Funcin " },
		{ 24, "Disable Flying Start|es|Deshabilita FlyStart" },
		{ 25, "Not Used|es|Sin Funcin " },
		{ 26, "Program. Off|es|Bloquea Programa" },
		{ 27, "Load User 1|es|Carga User 1" },
		{ 28, "Load User 2|es|Carga User 2" },
		{ 29, "PTC|es|PTC" },
		{ 30, "Not Used|es|Sin Funcin " },
		{ 31, "Not Used|es|Sin Funcin " },
		{ 32, "2nd ramp Multispeed|es|Multispeed 2 rampa" },
		{ 33, "2nd ramp Increase EP|es|Acelera EP 2 rampa" },
		{ 34, "2nd ramp Decrease EP|es|Desacelera EP 2 rampa" },
		{ 35, "2nd ramp FWD Run |es|Avance 2 rampa " },
		{ 36, "2nd ramp REV Run |es|Retroceso 2 rampa" },
		{ 37, "Start / Inc. EP|es|Comenza / Ac. EP" },
		{ 38, "Dec. EP / Stop|es|De. EP / Para" },
		{ 39, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 40, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 41, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 42, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 43, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 44, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 45, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 46, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 20;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0265
	}
}

COMMAND READ_P0265
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0265 }
	}
}

METHOD SET_PAR_NUMBER_0265
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 265;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0265 LIKE READ_P0265
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 9, P0265 }
		REPLY { }
	}
}

VARIABLE P0266
{
	LABEL "P0266 DI4 Function|es|P0266 Funcin Entrada DI4";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used|es|Sin Funcin " },
		{ 1, "Run/Stop|es|Gira/Para " },
		{ 2, "General Enable|es|Hab. General" },
		{ 3, "Quick Stop|es|Parada Rpida" },
		{ 4, "FWD Run |es|Avance" },
		{ 5, "REV Run |es|Retroceso " },
		{ 6, "Start |es|Start " },
		{ 7, "Stop|es|Stop" },
		{ 8, "FWD/REV |es|Sentido Giro Horario " },
		{ 9, "LOC/REM |es|LOC/REM " },
		{ 10, "JOG |es|JOG " },
		{ 11, "Increase EP|es|Acelera EP" },
		{ 12, "Decrease EP|es|Desacelera EP" },
		{ 13, "Multispeed |es|Multispeed " },
		{ 14, "2nd Ramp|es|2 Rampa" },
		{ 15, "Not Used|es|Sin Funcin " },
		{ 16, "Not Used|es|Sin Funcin " },
		{ 17, "Not Used|es|Sin Funcin " },
		{ 18, "No Ext. Alarm|es|Sin Alarma Ext" },
		{ 19, "No Ext. Fault|es|Sin Falla Ext." },
		{ 20, "Reset|es|Reset " },
		{ 21, "SoftPLC|es|SoftPLC" },
		{ 22, "Manual/Auto PID|es|Manual/Autom. PID" },
		{ 23, "Not Used|es|Sin Funcin " },
		{ 24, "Disab.FlyStart|es|Deshabilita FlyStart" },
		{ 25, "Not Used|es|Sin Funcin " },
		{ 26, "Program. Off|es|Bloquea Programa" },
		{ 27, "Load User 1|es|Carga User 1" },
		{ 28, "Load User 2|es|Carga User 2" },
		{ 29, "PTC|es|PTC" },
		{ 30, "Not Used|es|Sin Funcin " },
		{ 31, "Not Used|es|Sin Funcin " },
		{ 32, "2nd ramp Multispeed|es|Multispeed 2 rampa" },
		{ 33, "2nd ramp Increase EP|es|Acelera EP 2 rampa" },
		{ 34, "2nd ramp Decrease EP|es|Desacelera EP 2 rampa" },
		{ 35, "2nd ramp FWD Run |es|Avance 2 rampa " },
		{ 36, "2nd ramp REV Run |es|Retroceso 2 rampa" },
		{ 37, "Start / Inc. EP|es|Comenza / Ac. EP" },
		{ 38, "Dec. EP / Stop|es|De. EP / Para" },
		{ 39, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 40, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 41, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 42, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 43, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 44, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 45, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 46, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 9;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0266
	}
}

COMMAND READ_P0266
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0266 }
	}
}

METHOD SET_PAR_NUMBER_0266
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 266;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0266 LIKE READ_P0266
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 10, P0266 }
		REPLY { }
	}
}

VARIABLE P0267
{
	LABEL "P0267 DI5 Function|es|P0267 Funcin Entrada DI5";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used|es|Sin Funcin " },
		{ 1, "Run/Stop|es|Gira/Para " },
		{ 2, "General Enable|es|Hab. General" },
		{ 3, "Quick Stop|es|Parada Rpida" },
		{ 4, "FWD Run |es|Avance" },
		{ 5, "REV Run |es|Retroceso " },
		{ 6, "Start |es|Start " },
		{ 7, "Stop|es|Stop" },
		{ 8, "FWD/REV |es|Sentido Giro Horario " },
		{ 9, "LOC/REM |es|LOC/REM " },
		{ 10, "JOG |es|JOG " },
		{ 11, "Increase EP|es|Acelera EP" },
		{ 12, "Decrease EP|es|Desacelera EP" },
		{ 13, "Multispeed |es|Multispeed " },
		{ 14, "2nd Ramp|es|2 Rampa" },
		{ 15, "Not Used|es|Sin Funcin " },
		{ 16, "Not Used|es|Sin Funcin " },
		{ 17, "Not Used|es|Sin Funcin " },
		{ 18, "No Ext. Alarm|es|Sin Alarma Ext" },
		{ 19, "No Ext. Fault|es|Sin Falla Ext." },
		{ 20, "Reset|es|Reset " },
		{ 21, "SoftPLC|es|SoftPLC" },
		{ 22, "Manual/Auto PID|es|Manual/Autom. PID" },
		{ 23, "Not Used|es|Sin Funcin " },
		{ 24, "Disab.FlyStart|es|Deshabilita FlyStart" },
		{ 25, "Not Used|es|Sin Funcin " },
		{ 26, "Program. Off|es|Bloquea Programa" },
		{ 27, "Load User 1|es|Carga User 1" },
		{ 28, "Load User 2|es|Carga User 2" },
		{ 29, "PTC|es|PTC" },
		{ 30, "Not Used|es|Sin Funcin " },
		{ 31, "Not Used|es|Sin Funcin " },
		{ 32, "2nd ramp Multispeed|es|Multispeed 2 rampa" },
		{ 33, "2nd ramp Increase EP|es|Acelera EP 2 rampa" },
		{ 34, "2nd ramp Decrease EP|es|Desacelera EP 2 rampa" },
		{ 35, "2nd ramp FWD Run |es|Avance 2 rampa " },
		{ 36, "2nd ramp REV Run |es|Retroceso 2 rampa" },
		{ 37, "Start / Inc. EP|es|Comenza / Ac. EP" },
		{ 38, "Dec. EP / Stop|es|De. EP / Para" },
		{ 39, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 40, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 41, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 42, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 43, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 44, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 45, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 46, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0267
	}
}

COMMAND READ_P0267
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0267 }
	}
}

METHOD SET_PAR_NUMBER_0267
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 267;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0267 LIKE READ_P0267
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 11, P0267 }
		REPLY { }
	}
}

VARIABLE P0268
{
	LABEL "P0268 DI6 Function|es|P0268 Funcin Entrada DI6 ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used|es|Sin Funcin " },
		{ 1, "Run/Stop|es|Gira/Para " },
		{ 2, "General Enable|es|Hab. General" },
		{ 3, "Quick Stop|es|Parada Rpida" },
		{ 4, "FWD Run |es|Avance" },
		{ 5, "REV Run |es|Retroceso " },
		{ 6, "Start |es|Start " },
		{ 7, "Stop|es|Stop" },
		{ 8, "FWD/REV |es|Sentido Giro Horario " },
		{ 9, "LOC/REM |es|LOC/REM " },
		{ 10, "JOG |es|JOG " },
		{ 11, "Increase EP|es|Acelera EP" },
		{ 12, "Decrease EP|es|Desacelera EP" },
		{ 13, "Multispeed |es|Multispeed " },
		{ 14, "2nd Ramp|es|2 Rampa" },
		{ 15, "Not Used|es|Sin Funcin " },
		{ 16, "Not Used|es|Sin Funcin " },
		{ 17, "Not Used|es|Sin Funcin " },
		{ 18, "No Ext. Alarm|es|Sin Alarma Ext" },
		{ 19, "No Ext. Fault|es|Sin Falla Ext." },
		{ 20, "Reset|es|Reset " },
		{ 21, "SoftPLC|es|SoftPLC" },
		{ 22, "Manual/Auto PID|es|Manual/Autom. PID" },
		{ 23, "Not Used|es|Sin Funcin " },
		{ 24, "Disab.FlyStart|es|Deshabilita FlyStart" },
		{ 25, "Not Used|es|Sin Funcin " },
		{ 26, "Program. Off|es|Bloquea Programa" },
		{ 27, "Load User 1|es|Carga User 1" },
		{ 28, "Load User 2|es|Carga User 2" },
		{ 29, "PTC|es|PTC" },
		{ 30, "Not Used|es|Sin Funcin " },
		{ 31, "Not Used|es|Sin Funcin " },
		{ 32, "2nd ramp Multispeed|es|Multispeed 2 rampa" },
		{ 33, "2nd ramp Increase EP|es|Acelera EP 2 rampa" },
		{ 34, "2nd ramp Decrease EP|es|Desacelera EP 2 rampa" },
		{ 35, "2nd ramp FWD Run |es|Avance 2 rampa " },
		{ 36, "2nd ramp REV Run |es|Retroceso 2 rampa" },
		{ 37, "Start / Inc. EP|es|Comenza / Ac. EP" },
		{ 38, "Dec. EP / Stop|es|De. EP / Para" },
		{ 39, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 40, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 41, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 42, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 43, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 44, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 45, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 46, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0268
	}
}

COMMAND READ_P0268
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0268 }
	}
}

METHOD SET_PAR_NUMBER_0268
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 268;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0268 LIKE READ_P0268
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 12, P0268 }
		REPLY { }
	}
}

VARIABLE P0269
{
	LABEL "P0269 DI7 Function|es|P0269 Funcin Entrada DI7";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used|es|Sin Funcin " },
		{ 1, "Run/Stop|es|Gira/Para " },
		{ 2, "General Enable|es|Hab. General" },
		{ 3, "Quick Stop|es|Parada Rpida" },
		{ 4, "FWD Run |es|Avance" },
		{ 5, "REV Run |es|Retroceso " },
		{ 6, "Start |es|Start " },
		{ 7, "Stop|es|Stop" },
		{ 8, "FWD/REV |es|Sentido Giro Horario " },
		{ 9, "LOC/REM |es|LOC/REM " },
		{ 10, "JOG |es|JOG " },
		{ 11, "Increase EP|es|Acelera EP" },
		{ 12, "Decrease EP|es|Desacelera EP" },
		{ 13, "Multispeed |es|Multispeed " },
		{ 14, "2nd Ramp|es|2 Rampa" },
		{ 15, "Not Used|es|Sin Funcin " },
		{ 16, "Not Used|es|Sin Funcin " },
		{ 17, "Not Used|es|Sin Funcin " },
		{ 18, "No Ext. Alarm|es|Sin Alarma Ext" },
		{ 19, "No Ext. Fault|es|Sin Falla Ext." },
		{ 20, "Reset|es|Reset " },
		{ 21, "SoftPLC|es|SoftPLC" },
		{ 22, "Manual/Auto PID|es|Manual/Autom. PID" },
		{ 23, "Not Used|es|Sin Funcin " },
		{ 24, "Disab.FlyStart|es|Deshabilita FlyStart" },
		{ 25, "Not Used|es|Sin Funcin " },
		{ 26, "Program. Off|es|Bloquea Programa" },
		{ 27, "Load User 1|es|Carga User 1" },
		{ 28, "Load User 2|es|Carga User 2" },
		{ 29, "PTC|es|PTC" },
		{ 30, "Not Used|es|Sin Funcin " },
		{ 31, "Not Used|es|Sin Funcin " },
		{ 32, "2nd ramp Multispeed|es|Multispeed 2 rampa" },
		{ 33, "2nd ramp Increase EP|es|Acelera EP 2 rampa" },
		{ 34, "2nd ramp Decrease EP|es|Desacelera EP 2 rampa" },
		{ 35, "2nd ramp FWD Run |es|Avance 2 rampa " },
		{ 36, "2nd ramp REV Run |es|Retroceso 2 rampa" },
		{ 37, "Start / Inc. EP|es|Comenza / Ac. EP" },
		{ 38, "Dec. EP / Stop|es|De. EP / Para" },
		{ 39, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 40, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 41, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 42, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 43, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 44, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 45, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 46, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0269
	}
}

COMMAND READ_P0269
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0269 }
	}
}

METHOD SET_PAR_NUMBER_0269
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 269;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0269 LIKE READ_P0269
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 13, P0269 }
		REPLY { }
	}
}

VARIABLE P0270
{
	LABEL "P0270 DI8 Function|es|P0270 Funcin Entrada DI8";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used|es|Sin Funcin " },
		{ 1, "Run/Stop|es|Gira/Para " },
		{ 2, "General Enable|es|Hab. General" },
		{ 3, "Quick Stop|es|Parada Rpida" },
		{ 4, "FWD Run |es|Avance" },
		{ 5, "REV Run |es|Retroceso " },
		{ 6, "Start |es|Start " },
		{ 7, "Stop|es|Stop" },
		{ 8, "FWD/REV |es|Sentido Giro Horario " },
		{ 9, "LOC/REM |es|LOC/REM " },
		{ 10, "JOG |es|JOG " },
		{ 11, "Increase EP|es|Acelera EP" },
		{ 12, "Decrease EP|es|Desacelera EP" },
		{ 13, "Multispeed |es|Multispeed " },
		{ 14, "2nd Ramp|es|2 Rampa" },
		{ 15, "Not Used|es|Sin Funcin " },
		{ 16, "Not Used|es|Sin Funcin " },
		{ 17, "Not Used|es|Sin Funcin " },
		{ 18, "No Ext. Alarm|es|Sin Alarma Ext" },
		{ 19, "No Ext. Fault|es|Sin Falla Ext." },
		{ 20, "Reset|es|Reset " },
		{ 21, "SoftPLC|es|SoftPLC" },
		{ 22, "Manual/Auto PID|es|Manual/Autom. PID" },
		{ 23, "Not Used|es|Sin Funcin " },
		{ 24, "Disab.FlyStart|es|Deshabilita FlyStart" },
		{ 25, "Not Used|es|Sin Funcin " },
		{ 26, "Program. Off|es|Bloquea Programa" },
		{ 27, "Load User 1|es|Carga User 1" },
		{ 28, "Load User 2|es|Carga User 2" },
		{ 29, "PTC|es|PTC" },
		{ 30, "Not Used|es|Sin Funcin " },
		{ 31, "Not Used|es|Sin Funcin " },
		{ 32, "2nd ramp Multispeed|es|Multispeed 2 rampa" },
		{ 33, "2nd ramp Increase EP|es|Acelera EP 2 rampa" },
		{ 34, "2nd ramp Decrease EP|es|Desacelera EP 2 rampa" },
		{ 35, "2nd ramp FWD Run|es|Avance 2 rampa " },
		{ 36, "2nd ramp REV Run|es|Retroceso 2 rampa" },
		{ 37, "Start / Inc. EP|es|Comenza / Ac. EP" },
		{ 38, "Dec. EP / Stop|es|De. EP / Para" },
		{ 39, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 40, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 41, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 42, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 43, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 44, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 45, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 46, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0270
	}
}

COMMAND READ_P0270
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0270 }
	}
}

METHOD SET_PAR_NUMBER_0270
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 270;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0270 LIKE READ_P0270
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 14, P0270 }
		REPLY { }
	}
}

VARIABLE P0271
{
	LABEL "P0271 DI1 Function|es|P0271 Funcin Entrada DI1";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "(DI1..DI8)NPN|es|(DI1..DI8)NPN" },
		{ 1, "DI1 PNP|es|DI1 PNP" },
		{ 2, "(DI1..DI2)PNP|es|(DI1..DI2)PNP" },
		{ 3, "(DI1..DI3)PNP|es|(DI1..DI3)PNP" },
		{ 4, "(DI1..DI4)PNP|es|(DI1..DI4)PNP" },
		{ 5, "(DI1..DI5)PNP|es|(DI1..DI5)PNP" },
		{ 6, "(DI1..DI6)PNP|es|(DI1..DI6)PNP" },
		{ 7, "(DI1..DI7)PNP|es|(DI1..DI7)PNP" },
		{ 8, "(DI1..DI8)PNP|es|(DI1..DI8)PNP" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0271
	}
}

COMMAND READ_P0271
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0271 }
	}
}

METHOD SET_PAR_NUMBER_0271
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 271;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0271 LIKE READ_P0271
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 15, P0271 }
		REPLY { }
	}
}

VARIABLE P0275
{
	LABEL "P0275 DO1 Function|es|P0275 Funcin de salida DO1";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used|es|Sin Funcin " },
		{ 1, "F* > Fx |es|F* > Fx " },
		{ 2, "F > Fx|es|F > Fx" },
		{ 3, "F < Fx|es|F < Fx" },
		{ 4, "F = F*|es|F = F*" },
		{ 5, "Not Used|es|Sin Funcin " },
		{ 6, "Is > Ix |es|Is > Ix " },
		{ 7, "Is < Ix |es|Is < Ix " },
		{ 8, "Torque > Tx |es|Torque(Par) > Tx " },
		{ 9, "Torque < Tx |es|Torque(Par) < Tx " },
		{ 10, "Remote|es|Remoto" },
		{ 11, "Run |es|Run " },
		{ 12, "Ready |es|Ready " },
		{ 13, "No Fault|es|Sin Falla " },
		{ 14, "No F070|es|Sin F070 " },
		{ 15, "Not Used|es|Sin Funcin " },
		{ 16, "No F0021/22|es|Sin F0021/22" },
		{ 17, "Not Used|es|Sin Funcin " },
		{ 18, "No F072|es|Sin F072 " },
		{ 19, "4-20mA OK|es|4-20mA OK" },
		{ 20, "P0695 Value|es|Contenido P0695" },
		{ 21, "Forward |es|Sent. Horario" },
		{ 22, "Proc. V. > PVx|es|V. Proc. > VPx" },
		{ 23, "Proc. V. < PVx|es|V. Proc. < VPx" },
		{ 24, "Ride-Through|es|Ride-Through" },
		{ 25, "Pre-Charge OK |es|Precarga OK" },
		{ 26, "Fault|es|Con Falla" },
		{ 27, "Not Used|es|Sin Funcin " },
		{ 28, "SoftPLC|es|SoftPLC" },
		{ 29, "Not Used|es|Sin Funcin " },
		{ 30, "Not Used|es|Sin Funcin " },
		{ 31, "Not Used|es|Sin Funcin " },
		{ 32, "Not Used|es|Sin Funcin " },
		{ 33, "Not Used|es|Sin Funcin " },
		{ 34, "Not Used|es|Sin Funcin " },
		{ 35, "No Alarm|es|Sin Alarma" },
		{ 36, "No Fault/Alarm|es|Sin Falla/Alarma" },
		{ 37, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 38, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 39, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 40, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 41, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 42, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 43, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 44, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 13;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0275
	}
}

COMMAND READ_P0275
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0275 }
	}
}

METHOD SET_PAR_NUMBER_0275
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 275;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0275 LIKE READ_P0275
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 19, P0275 }
		REPLY { }
	}
}

VARIABLE P0276
{
	LABEL "P0276 DO2 Function|es|P0276 Funcin de salida DO2";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used|es|Sin Funcin " },
		{ 1, "F* > Fx |es|F* > Fx " },
		{ 2, "F > Fx|es|F > Fx" },
		{ 3, "F < Fx|es|F < Fx" },
		{ 4, "F = F*|es|F = F*" },
		{ 5, "Not Used|es|Sin Funcin " },
		{ 6, "Is > Ix |es|Is > Ix " },
		{ 7, "Is < Ix |es|Is < Ix " },
		{ 8, "Torque > Tx |es|Torque(Par) > Tx " },
		{ 9, "Torque < Tx |es|Torque(Par) < Tx " },
		{ 10, "Remote|es|Remoto" },
		{ 11, "Run |es|Run " },
		{ 12, "Ready |es|Ready " },
		{ 13, "No Fault|es|Sin Falla " },
		{ 14, "No F070|es|Sin F070 " },
		{ 15, "Not Used|es|Sin Funcin " },
		{ 16, "No F0021/22|es|Sin F0021/22" },
		{ 17, "Not Used|es|Sin Funcin " },
		{ 18, "No F072|es|Sin F072 " },
		{ 19, "4-20mA OK|es|4-20mA OK" },
		{ 20, "P0695 Value|es|Contenido P0695" },
		{ 21, "Forward |es|Sent. Horario" },
		{ 22, "Proc. V. > PVx|es|V. Proc. > VPx" },
		{ 23, "Proc. V. < PVx|es|V. Proc. < VPx" },
		{ 24, "Ride-Through|es|Ride-Through" },
		{ 25, "Pre-Charge OK |es|Precarga OK" },
		{ 26, "Fault|es|Con Falla" },
		{ 27, "Not Used|es|Sin Funcin " },
		{ 28, "SoftPLC|es|SoftPLC" },
		{ 29, "Not Used|es|Sin Funcin " },
		{ 30, "Not Used|es|Sin Funcin " },
		{ 31, "Not Used|es|Sin Funcin " },
		{ 32, "Not Used|es|Sin Funcin " },
		{ 33, "Not Used|es|Sin Funcin " },
		{ 34, "Not Used|es|Sin Funcin " },
		{ 35, "No Alarm|es|Sin Alarma" },
		{ 36, "No Fault/Alarm|es|Sin Falla/Alarma" },
		{ 37, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 38, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 39, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 40, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 41, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 42, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 43, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 44, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0276
	}
}

COMMAND READ_P0276
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0276 }
	}
}

METHOD SET_PAR_NUMBER_0276
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 276;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0276 LIKE READ_P0276
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 20, P0276 }
		REPLY { }
	}
}

VARIABLE P0277
{
	LABEL "P0277 DO3 Function|es|P0277 Funcin de salida DO3";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used|es|Sin Funcin " },
		{ 1, "N* > Fx |es|N* > Fx " },
		{ 2, "N > Fx|es|N > Fx" },
		{ 3, "F < Fx|es|F < Fx" },
		{ 4, "N = N*|es|N = N*" },
		{ 5, "Not Used|es|Sin Funcin " },
		{ 6, "Is > Ix |es|Is > Ix " },
		{ 7, "Is < Ix |es|Is < Ix " },
		{ 8, "Torque > Tx |es|Torque(Par) > Tx " },
		{ 9, "Torque < Tx |es|Torque(Par) < Tx " },
		{ 10, "Remote|es|Remoto" },
		{ 11, "Run |es|Run " },
		{ 12, "Ready |es|Ready " },
		{ 13, "No Fault|es|Sin Falla " },
		{ 14, "No F070|es|Sin F070 " },
		{ 15, "Not Used|es|Sin Funcin " },
		{ 16, "No F0021/22|es|Sin F0021/22" },
		{ 17, "Not Used|es|Sin Funcin " },
		{ 18, "No F072|es|Sin F072 " },
		{ 19, "4-20mA OK|es|4-20mA OK" },
		{ 20, "P0695 Value|es|Contenido P0695" },
		{ 21, "Forward |es|Sent. Horario" },
		{ 22, "Proc. V. > PVx|es|V. Proc. > VPx" },
		{ 23, "Proc. V. < PVx|es|V. Proc. < VPx" },
		{ 24, "Ride-Through|es|Ride-Through" },
		{ 25, "Pre-Charge OK |es|Precarga OK" },
		{ 26, "Fault|es|Con Falla" },
		{ 27, "Not Used|es|Sin Funcin " },
		{ 28, "SoftPLC|es|SoftPLC" },
		{ 29, "Not Used|es|Sin Funcin " },
		{ 30, "Not Used|es|Sin Funcin " },
		{ 31, "Not Used|es|Sin Funcin " },
		{ 32, "Not Used|es|Sin Funcin " },
		{ 33, "Not Used|es|Sin Funcin " },
		{ 34, "Not Used|es|Sin Funcin " },
		{ 35, "No Alarm|es|Sin Alarma" },
		{ 36, "No Fault/Alarm|es|Sin Falla/Alarma" },
		{ 37, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 38, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 39, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 40, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 41, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 42, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 43, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 44, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0277
	}
}

COMMAND READ_P0277
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0277 }
	}
}

METHOD SET_PAR_NUMBER_0277
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 277;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0277 LIKE READ_P0277
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 21, P0277 }
		REPLY { }
	}
}

VARIABLE P0278
{
	LABEL "P0278 DO4 Function|es|P0278 Funcin de salida DO4";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used|es|Sin Funcin " },
		{ 1, "N* > Fx |es|N* > Fx " },
		{ 2, "F > Fx|es|F > Fx" },
		{ 3, "F < Fx|es|F < Fx" },
		{ 4, "N = N*|es|N = N*" },
		{ 5, "Not Used|es|Sin Funcin " },
		{ 6, "Is > Ix |es|Is > Ix " },
		{ 7, "Is < Ix |es|Is < Ix " },
		{ 8, "Torque > Tx |es|Torque(Par) > Tx " },
		{ 9, "Torque < Tx |es|Torque(Par) < Tx " },
		{ 10, "Remote|es|Remoto" },
		{ 11, "Run |es|Run " },
		{ 12, "Ready |es|Ready " },
		{ 13, "No Fault|es|Sin Falla " },
		{ 14, "No F070|es|Sin F070 " },
		{ 15, "Not Used|es|Sin Funcin " },
		{ 16, "No F0021/22|es|Sin F0021/22" },
		{ 17, "Not Used|es|Sin Funcin " },
		{ 18, "No F072|es|Sin F072 " },
		{ 19, "4-20mA OK|es|4-20mA OK" },
		{ 20, "P0695 Value|es|Contenido P0695" },
		{ 21, "Forward |es|Sent. Horario" },
		{ 22, "Proc. V. > PVx|es|V. Proc. > VPx" },
		{ 23, "Proc. V. < PVx|es|V. Proc. < VPx" },
		{ 24, "Ride-Through|es|Ride-Through" },
		{ 25, "Pre-Charge OK |es|Precarga OK" },
		{ 26, "Fault|es|Con Falla" },
		{ 27, "Not Used|es|Sin Funcin " },
		{ 28, "SoftPLC|es|SoftPLC" },
		{ 29, "Not Used|es|Sin Funcin " },
		{ 30, "Not Used|es|Sin Funcin " },
		{ 31, "Not Used|es|Sin Funcin " },
		{ 32, "Not Used|es|Sin Funcin " },
		{ 33, "Not Used|es|Sin Funcin " },
		{ 34, "Not Used|es|Sin Funcin " },
		{ 35, "No Alarm|es|Sin Alarma" },
		{ 36, "No Fault/Alarm|es|Sin Falla/Alarma" },
		{ 37, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 38, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 39, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 40, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 41, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 42, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 43, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 44, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0278
	}
}

COMMAND READ_P0278
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0278 }
	}
}

METHOD SET_PAR_NUMBER_0278
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 278;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0278 LIKE READ_P0278
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 22, P0278 }
		REPLY { }
	}
}

VARIABLE P0279
{
	LABEL "P0279 DO5 Function|es|P0279 Funcin de salida DO5";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Not Used|es|Sin Funcin " },
		{ 1, "N* > Fx |es|N* > Fx " },
		{ 2, "F > Fx|es|F > Fx" },
		{ 3, "F < Fx|es|F < Fx" },
		{ 4, "N = N*|es|N = N*" },
		{ 5, "Not Used|es|Sin Funcin " },
		{ 6, "Is > Ix |es|Is > Ix " },
		{ 7, "Is < Ix |es|Is < Ix " },
		{ 8, "Torque > Tx |es|Torque(Par) > Tx " },
		{ 9, "Torque < Tx |es|Torque(Par) < Tx " },
		{ 10, "Remote|es|Remoto" },
		{ 11, "Run |es|Run " },
		{ 12, "Ready |es|Ready " },
		{ 13, "No Fault|es|Sin Falla " },
		{ 14, "No F070|es|Sin F070 " },
		{ 15, "Not Used|es|Sin Funcin " },
		{ 16, "No F0021/22|es|Sin F0021/22" },
		{ 17, "Not Used|es|Sin Funcin " },
		{ 18, "No F072|es|Sin F072 " },
		{ 19, "4-20mA OK|es|4-20mA OK" },
		{ 20, "P0695 Value|es|Contenido P0695" },
		{ 21, "Forward |es|Sent. Horario" },
		{ 22, "Proc. V. > PVx|es|V. Proc. > VPx" },
		{ 23, "Proc. V. < PVx|es|V. Proc. < VPx" },
		{ 24, "Ride-Through|es|Ride-Through" },
		{ 25, "Pre-Charge OK |es|Precarga OK" },
		{ 26, "Fault|es|Con Falla" },
		{ 27, "Not Used|es|Sin Funcin " },
		{ 28, "SoftPLC|es|SoftPLC" },
		{ 29, "Not Used|es|Sin Funcin " },
		{ 30, "Not Used|es|Sin Funcin " },
		{ 31, "Not Used|es|Sin Funcin " },
		{ 32, "Not Used|es|Sin Funcin " },
		{ 33, "Not Used|es|Sin Funcin " },
		{ 34, "Not Used|es|Sin Funcin " },
		{ 35, "No Alarm|es|Sin Alarma" },
		{ 36, "No Fault/Alarm|es|Sin Falla/Alarma" },
		{ 37, "Application Function 1|es|Funcin 1 Aplicacin" },
		{ 38, "Application Function 2|es|Funcin 2 Aplicacin" },
		{ 39, "Application Function 3|es|Funcin 3 Aplicacin" },
		{ 40, "Application Function 4|es|Funcin 4 Aplicacin" },
		{ 41, "Application Function 5|es|Funcin 5 Aplicacin" },
		{ 42, "Application Function 6|es|Funcin 6 Aplicacin" },
		{ 43, "Application Function 7|es|Funcin 7 Aplicacin" },
		{ 44, "Application Function 8|es|Funcin 8 Aplicacin" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0279
	}
}

COMMAND READ_P0279
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0279 }
	}
}

METHOD SET_PAR_NUMBER_0279
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 279;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0279 LIKE READ_P0279
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 23, P0279 }
		REPLY { }
	}
}

VARIABLE P0287
{
	LABEL "P0287 Fx Hysteresis|es|P0287 Histresis Fx";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0.5;
		MIN_VALUE 0;
		MAX_VALUE 10;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0287
	}
}

COMMAND READ_P0287
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0287 }
	}
}

METHOD SET_PAR_NUMBER_0287
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 287;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0287 LIKE READ_P0287
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 31, P0287 }
		REPLY { }
	}
}

VARIABLE P0288
{
	LABEL "P0288 Fx Speed|es|P0288 Velocidad Fx";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 3;
		MIN_VALUE 0;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0288
	}
}

COMMAND READ_P0288
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0288 }
	}
}

METHOD SET_PAR_NUMBER_0288
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 288;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0288 LIKE READ_P0288
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 32, P0288 }
		REPLY { }
	}
}

VARIABLE P0290
{
	LABEL "P0290 Ix Current|es|P0290 Corriente Ix";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0290
	}
}

COMMAND READ_P0290
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0290 }
	}
}

METHOD SET_PAR_NUMBER_0290
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 290;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0290 LIKE READ_P0290
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 34, P0290 }
		REPLY { }
	}
}

VARIABLE P0293
{
	LABEL "P0293 Tx Torque |es|P0293 Torque(Par) Tx ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 100;
		MIN_VALUE 0;
		MAX_VALUE 200;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0293
	}
}

COMMAND READ_P0293
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0293 }
	}
}

METHOD SET_PAR_NUMBER_0293
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 293;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0293 LIKE READ_P0293
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 37, P0293 }
		REPLY { }
	}
}

VARIABLE P0294
{
	LABEL "P0294 Hx Time|es|P0294 Horas Hx ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 432;
		MIN_VALUE 0;
		MAX_VALUE 6553.5;
	}
	CONSTANT_UNIT "h";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0294
	}
}

COMMAND READ_P0294
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0294 }
	}
}

METHOD SET_PAR_NUMBER_0294
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 294;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0294 LIKE READ_P0294
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 38, P0294 }
		REPLY { }
	}
}

VARIABLE P0295
{
	LABEL "P0295 ND/HD VFD Rated Curr.|es|P0295 Corr.Nomin.ND/HD Conv";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "A";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0295
	}
}

COMMAND READ_P0295
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0295 }
	}
}

METHOD SET_PAR_NUMBER_0295
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 295;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0296
{
	LABEL "P0296 Line Rated Voltage |es|P0296 Tensin Nominal Red";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "200 - 240 V |es|200 - 240 V " },
		{ 1, "380 - 480 V |es|380 - 480 V " },
		{ 2, "500 - 600 V|es|500 - 600 V" }
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0296
	}
}

COMMAND READ_P0296
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0296 }
	}
}

METHOD SET_PAR_NUMBER_0296
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 296;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0297
{
	LABEL "P0297 Switching Frequency|es|P0297 Frec. Conmutacin";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 4000;
		MIN_VALUE 1500;
		MAX_VALUE 15000;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0297
	}
}

COMMAND READ_P0297
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0297 }
	}
}

METHOD SET_PAR_NUMBER_0297
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 297;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0297 LIKE READ_P0297
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 41, P0297 }
		REPLY { }
	}
}

VARIABLE P0299
{
	LABEL "P0299 DC-Braking Start Time|es|P0299 Tiempo Fren. Partida ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 15;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0299
	}
}

COMMAND READ_P0299
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0299 }
	}
}

METHOD SET_PAR_NUMBER_0299
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 299;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0299 LIKE READ_P0299
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 43, P0299 }
		REPLY { }
	}
}

VARIABLE P0300
{
	LABEL "P0300 DC-Braking Stop Time|es|P0300 Tiempo Fren. Parada ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 15;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0300
	}
}

COMMAND READ_P0300
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0300 }
	}
}

METHOD SET_PAR_NUMBER_0300
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 300;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0300 LIKE READ_P0300
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 44, P0300 }
		REPLY { }
	}
}

VARIABLE P0301
{
	LABEL "P0301 DC-Braking Frequency|es|P0301 Frecuencia de Inicio";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 3;
		MIN_VALUE 0;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0301
	}
}

COMMAND READ_P0301
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0301 }
	}
}

METHOD SET_PAR_NUMBER_0301
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 301;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0301 LIKE READ_P0301
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 45, P0301 }
		REPLY { }
	}
}

VARIABLE P0302
{
	LABEL "P0302 DC-Braking Voltage|es|P0302 Tensin Frenado CC";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 20;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0302
	}
}

COMMAND READ_P0302
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0302 }
	}
}

METHOD SET_PAR_NUMBER_0302
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 302;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0302 LIKE READ_P0302
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 46, P0302 }
		REPLY { }
	}
}

VARIABLE P0303
{
	LABEL "P0303 Skip Frequency 1|es|P0303 Frecuencia Rechazada 1";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 20;
		MIN_VALUE 0;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0303
	}
}

COMMAND READ_P0303
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0303 }
	}
}

METHOD SET_PAR_NUMBER_0303
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 303;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0303 LIKE READ_P0303
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 47, P0303 }
		REPLY { }
	}
}

VARIABLE P0304
{
	LABEL "P0304 Skip Frequency 2|es|P0304 Frecuencia Rechazada 2";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 30;
		MIN_VALUE 0;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0304
	}
}

COMMAND READ_P0304
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0304 }
	}
}

METHOD SET_PAR_NUMBER_0304
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 304;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0304 LIKE READ_P0304
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 48, P0304 }
		REPLY { }
	}
}

VARIABLE P0306
{
	LABEL "P0306 Skip Band |es|P0306 Faja Rechazadoa";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 25;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0306
	}
}

COMMAND READ_P0306
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0306 }
	}
}

METHOD SET_PAR_NUMBER_0306
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 306;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0306 LIKE READ_P0306
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 50, P0306 }
		REPLY { }
	}
}

VARIABLE P0308
{
	LABEL "P0308 Serial Address |es|P0308 Direccin Serial";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 1;
		MAX_VALUE 247;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0308
	}
}

COMMAND READ_P0308
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0308 }
	}
}

METHOD SET_PAR_NUMBER_0308
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 308;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0308 LIKE READ_P0308
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 52, P0308 }
		REPLY { }
	}
}

VARIABLE P0310
{
	LABEL "P0310 Serial Baud Rate|es|P0310 Tasa Comunicacin Serial";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "9600 bits/s|es|9600 bits/s" },
		{ 1, "19200 bits/s|es|19200 bits/s" },
		{ 2, "38400 bits/s|es|38400 bits/s" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0310
	}
}

COMMAND READ_P0310
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0310 }
	}
}

METHOD SET_PAR_NUMBER_0310
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 310;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0310 LIKE READ_P0310
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 54, P0310 }
		REPLY { }
	}
}

VARIABLE P0311
{
	LABEL "P0311 Serial Bytes Config.|es|P0311 Configuracin Bytes Serial";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "8 bits, no, 1|es|8 bits, sin, 1" },
		{ 1, "8 bits, even,1|es|8 bits, par, 1" },
		{ 2, "8 bits, odd, 1|es|8 bits, imp, 1" },
		{ 3, "8 bits, no, 2|es|8 bits, sin, 2" },
		{ 4, "8 bits, even,2|es|8 bits, par, 2" },
		{ 5, "8 bits, odd, 2|es|8 bits, imp, 2" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0311
	}
}

COMMAND READ_P0311
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0311 }
	}
}

METHOD SET_PAR_NUMBER_0311
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 311;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0311 LIKE READ_P0311
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 55, P0311 }
		REPLY { }
	}
}

VARIABLE P0312
{
	LABEL "P0312 Serial Protocol (1)(2)|es|P0312 Protocolo Serial (1)(2)";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "HMI(1)|es|HMI(1)" },
		{ 1, "Reserved|es|Reservado" },
		{ 2, "Modbus RTU(1)|es|Modbus RTU(1)" },
		{ 3, "Reserved|es|Reservado" },
		{ 4, "Reserved|es|Reservado" },
		{ 5, "Reserved|es|Reservado" },
		{ 6, "HMI(1) and Modbus RTU(2)|es|HMI(1) y Modbus RTU(2)" },
		{ 7, "Modbus RTU(2)|es|Modbus RTU(2)" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0312
	}
}

COMMAND READ_P0312
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0312 }
	}
}

METHOD SET_PAR_NUMBER_0312
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 312;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0312 LIKE READ_P0312
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 56, P0312 }
		REPLY { }
	}
}

VARIABLE P0313
{
	LABEL "P0313 Comm. Error Action|es|P0313 Accin para Erro Comunicacin";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off|es|Inactivo" },
		{ 1, "Ramp Stop|es|Para por Rampa" },
		{ 2, "General Disab.|es|Deshabilita General" },
		{ 3, "Go to LOC|es|Ir p/ LOC" },
		{ 4, "LOC Keep Enab.|es|LOC Mantm Hab" },
		{ 5, "Cause Fault|es|Causa Falha" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0313
	}
}

COMMAND READ_P0313
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0313 }
	}
}

METHOD SET_PAR_NUMBER_0313
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 313;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0313 LIKE READ_P0313
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 57, P0313 }
		REPLY { }
	}
}

VARIABLE P0314
{
	LABEL "P0314 Serial Watchdog|es|P0314 Watchdog Serial";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 999;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0314
	}
}

COMMAND READ_P0314
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0314 }
	}
}

METHOD SET_PAR_NUMBER_0314
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 314;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0314 LIKE READ_P0314
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 58, P0314 }
		REPLY { }
	}
}

VARIABLE P0316
{
	LABEL "P0316 Serial Interf. Status|es|P0316 Estado Interf. Serial";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off|es|Inactivo" },
		{ 1, "On|es|Activo" },
		{ 2, "Watchdog Error|es|Error Watchdog" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0316
	}
}

COMMAND READ_P0316
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0316 }
	}
}

METHOD SET_PAR_NUMBER_0316
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 316;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0320
{
	LABEL "P0320 Flying Start/Ride-Through|es|P0320 FlyStart/Ride-Through";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off |es|Inactivas" },
		{ 1, "Flying Start (FS)|es|Flying Start (FS)" },
		{ 2, "FS and RT |es|FS e RT" },
		{ 3, "Ride-Through (RT)|es|Ride-Through (RT)" },
		{ 4, "FS by AI1 |es|FS por AI1" },
		{ 5, "FS by P0696|es|FS por AI1" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0320
	}
}

COMMAND READ_P0320
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0320 }
	}
}

METHOD SET_PAR_NUMBER_0320
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 320;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0320 LIKE READ_P0320
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 64, P0320 }
		REPLY { }
	}
}

VARIABLE P0331
{
	LABEL "P0331 Voltage Ramp|es|P0331 Rampa de Tensin";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 2;
		MIN_VALUE 0.2;
		MAX_VALUE 60;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0331
	}
}

COMMAND READ_P0331
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0331 }
	}
}

METHOD SET_PAR_NUMBER_0331
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 331;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0331 LIKE READ_P0331
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 75, P0331 }
		REPLY { }
	}
}

VARIABLE P0340
{
	LABEL "P0340 Auto-Reset Time |es|P0340 Tiempo AutoReset";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 255;
	}
	CONSTANT_UNIT "s";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0340
	}
}

COMMAND READ_P0340
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0340 }
	}
}

METHOD SET_PAR_NUMBER_0340
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 340;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0340 LIKE READ_P0340
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 84, P0340 }
		REPLY { }
	}
}

VARIABLE P0343
{
	LABEL "P0343 Fault Mask|es|P0343 ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 7;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0343
	}
}

COMMAND READ_P0343
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0343 }
	}
}

METHOD SET_PAR_NUMBER_0343
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 343;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0343 LIKE READ_P0343
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 87, P0343 }
		REPLY { }
	}
}

VARIABLE P0349
{
	LABEL "P0349 Ixt Alarm Level|es|P0349 Nivel para Alarma Ixt";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 85;
		MIN_VALUE 70;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0349
	}
}

COMMAND READ_P0349
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0349 }
	}
}

METHOD SET_PAR_NUMBER_0349
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 349;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0349 LIKE READ_P0349
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 93, P0349 }
		REPLY { }
	}
}

VARIABLE P0397
{
	LABEL "P0397 Control Config |es|P0397 Config. de control";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 63;
		MIN_VALUE 0;
		MAX_VALUE 63;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0397
	}
}

COMMAND READ_P0397
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0397 }
	}
}

METHOD SET_PAR_NUMBER_0397
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 397;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0397 LIKE READ_P0397
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 141, P0397 }
		REPLY { }
	}
}

VARIABLE P0399
{
	LABEL "P0399 Motor Rated Eff.|es|P0399 Rendimiento Nom.Motor";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 75;
		MIN_VALUE 50;
		MAX_VALUE 99.9;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0399
	}
}

COMMAND READ_P0399
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0399 }
	}
}

METHOD SET_PAR_NUMBER_0399
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 399;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0399 LIKE READ_P0399
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 143, P0399 }
		REPLY { }
	}
}

VARIABLE P0400
{
	LABEL "P0400 Motor Rated Voltage|es|P0400 Tensin Nominal Motor";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	CONSTANT_UNIT "V";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0400
	}
}

COMMAND READ_P0400
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0400 }
	}
}

METHOD SET_PAR_NUMBER_0400
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 400;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0400 LIKE READ_P0400
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 144, P0400 }
		REPLY { }
	}
}

VARIABLE P0401
{
	LABEL "P0401 Motor Rated Current|es|P0401 Corriente Nom. Motor";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
	}
	CONSTANT_UNIT "A";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0401
	}
}

COMMAND READ_P0401
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0401 }
	}
}

METHOD SET_PAR_NUMBER_0401
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 401;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0401 LIKE READ_P0401
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 145, P0401 }
		REPLY { }
	}
}

VARIABLE P0402
{
	LABEL "P0402 Motor Rated Speed |es|P0402 Rotacin Nom. Motor";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1710;
		MIN_VALUE 0;
		MAX_VALUE 30000;
	}
	CONSTANT_UNIT "rpm";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0402
	}
}

COMMAND READ_P0402
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0402 }
	}
}

METHOD SET_PAR_NUMBER_0402
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 402;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0402 LIKE READ_P0402
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 146, P0402 }
		REPLY { }
	}
}

VARIABLE P0403
{
	LABEL "P0403 Motor Rated Frequency|es|P0403 Frecuencia Nom. Motor";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 60;
		MIN_VALUE 0;
		MAX_VALUE 500;
	}
	CONSTANT_UNIT "Hz";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0403
	}
}

COMMAND READ_P0403
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0403 }
	}
}

METHOD SET_PAR_NUMBER_0403
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 403;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0403 LIKE READ_P0403
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 147, P0403 }
		REPLY { }
	}
}

VARIABLE P0404
{
	LABEL "P0404 Motor Rated Power|es|P0404 Potencia Nom. Motor ";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0404
	}
}

COMMAND READ_P0404
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0404 }
	}
}

METHOD SET_PAR_NUMBER_0404
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 404;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0404 LIKE READ_P0404
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 148, P0404 }
		REPLY { }
	}
}

VARIABLE P0406
{
	LABEL "P0406 Motor Ventilation|es|P0406 Ventilacin del Motor";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Self-Vent. |es|Autoventilado " },
		{ 1, "Separate Vent|es|Independente" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0406
	}
}

COMMAND READ_P0406
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0406 }
	}
}

METHOD SET_PAR_NUMBER_0406
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 406;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0406 LIKE READ_P0406
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 150, P0406 }
		REPLY { }
	}
}

VARIABLE P0407
{
	LABEL "P0407 Motor Rated Power Fac|es|P0407 Factor Pot.Nom. Motor";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
		DEFAULT_VALUE 0.8;
		MIN_VALUE 0.5;
		MAX_VALUE 0.99;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0407
	}
}

COMMAND READ_P0407
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0407 }
	}
}

METHOD SET_PAR_NUMBER_0407
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 407;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0407 LIKE READ_P0407
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 151, P0407 }
		REPLY { }
	}
}

VARIABLE P0409
{
	LABEL "P0409 Stator Resistance|es|P0409 Resistencia Estator";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.01;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0409
	}
}

COMMAND READ_P0409
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0409 }
	}
}

METHOD SET_PAR_NUMBER_0409
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 409;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0409 LIKE READ_P0409
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 153, P0409 }
		REPLY { }
	}
}

VARIABLE P0510
{
	LABEL "P0510 SoftPLC Eng. Unit 1 |es|P0510 Unidad Ing. 1 SoftPLC ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "None|es|Sin unidad" },
		{ 1, "V|es|V" },
		{ 2, "A|es|A" },
		{ 3, "rpm|es|rpm" },
		{ 4, "s|es|s" },
		{ 5, "ms|es|ms" },
		{ 6, "N|es|N" },
		{ 7, "m|es|m" },
		{ 8, "Nm|es|Nm" },
		{ 9, "mA|es|mA" },
		{ 10, "%|es|%" },
		{ 11, "C|es|C" },
		{ 12, "CV|es|CV" },
		{ 13, "Hz|es|Hz" },
		{ 14, "HP|es|HP" },
		{ 15, "h|es|h" },
		{ 16, "W|es|W" },
		{ 17, "kW|es|kW" },
		{ 18, "kWh|es|kWh" },
		{ 19, "H|es|H" }
		DEFAULT_VALUE 13;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0510
	}
}

COMMAND READ_P0510
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0510 }
	}
}

METHOD SET_PAR_NUMBER_0510
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 510;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0510 LIKE READ_P0510
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 254, P0510 }
		REPLY { }
	}
}

VARIABLE P0511
{
	LABEL "P0511 Decimal Point Uni. Eng. 1|es|P0511 Punto Decimal Uni. Ing. 1";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "wxyz|es|wxyz" },
		{ 1, "wxy.z|es|wxy.z" },
		{ 2, "wx.yz|es|wx.yz" },
		{ 3, "w.xyz|es|w.xyz" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0511
	}
}

COMMAND READ_P0511
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0511 }
	}
}

METHOD SET_PAR_NUMBER_0511
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 511;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0511 LIKE READ_P0511
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 1, 255, P0511 }
		REPLY { }
	}
}

VARIABLE P0512
{
	LABEL "P0512 SoftPLC Eng. Unit 2 |es|P0512 Unidad Ing. 2 SoftPLC ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "None|es|Sin unidad" },
		{ 1, "V|es|V" },
		{ 2, "A|es|A" },
		{ 3, "rpm|es|rpm" },
		{ 4, "s|es|s" },
		{ 5, "ms|es|ms" },
		{ 6, "N|es|N" },
		{ 7, "m|es|m" },
		{ 8, "Nm|es|Nm" },
		{ 9, "mA|es|mA" },
		{ 10, "%|es|%" },
		{ 11, "C|es|C" },
		{ 12, "CV|es|CV" },
		{ 13, "Hz|es|Hz" },
		{ 14, "HP|es|HP" },
		{ 15, "h|es|h" },
		{ 16, "W|es|W" },
		{ 17, "kW|es|kW" },
		{ 18, "kWh|es|kWh" },
		{ 19, "H|es|H" }
		DEFAULT_VALUE 13;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0512
	}
}

COMMAND READ_P0512
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0512 }
	}
}

METHOD SET_PAR_NUMBER_0512
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 512;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0512 LIKE READ_P0512
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 0, P0512 }
		REPLY { }
	}
}

VARIABLE P0513
{
	LABEL "P0513 Decimal Point Uni. Eng. 2|es|P0513 Punto Decimal Uni. Ing. 2";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "wxyz|es|wxyz" },
		{ 1, "wxy.z|es|wxy.z" },
		{ 2, "wx.yz|es|wx.yz" },
		{ 3, "w.xyz|es|w.xyz" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0513
	}
}

COMMAND READ_P0513
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0513 }
	}
}

METHOD SET_PAR_NUMBER_0513
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 513;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0513 LIKE READ_P0513
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 1, P0513 }
		REPLY { }
	}
}

VARIABLE P0520
{
	LABEL "P0520 PID Proportional Gain|es|P0520 Ganancia Prop. PID";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 1;
		MIN_VALUE 0;
		MAX_VALUE 9.999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0520
	}
}

COMMAND READ_P0520
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0520 }
	}
}

METHOD SET_PAR_NUMBER_0520
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 520;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0520 LIKE READ_P0520
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 8, P0520 }
		REPLY { }
	}
}

VARIABLE P0521
{
	LABEL "P0521 PID Integral Gain|es|P0521 Ganancia Integral PID";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 0.43;
		MIN_VALUE 0;
		MAX_VALUE 9.999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0521
	}
}

COMMAND READ_P0521
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0521 }
	}
}

METHOD SET_PAR_NUMBER_0521
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 521;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0521 LIKE READ_P0521
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 9, P0521 }
		REPLY { }
	}
}

VARIABLE P0522
{
	LABEL "P0522 PID Differential Gain|es|P0522 Ganancia Deriv. PID";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.001;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 9.999;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0522
	}
}

COMMAND READ_P0522
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0522 }
	}
}

METHOD SET_PAR_NUMBER_0522
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 522;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0522 LIKE READ_P0522
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 10, P0522 }
		REPLY { }
	}
}

VARIABLE P0525
{
	LABEL "P0525 Keypad PID Setpoint|es|P0525 Setpoint PID por HMI";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0525
	}
}

COMMAND READ_P0525
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0525 }
	}
}

METHOD SET_PAR_NUMBER_0525
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 525;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0525 LIKE READ_P0525
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 13, P0525 }
		REPLY { }
	}
}

VARIABLE P0526
{
	LABEL "P0526 PID Setpoint Filter|es|P0526 Filtro Setpoint PID";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 50;
		MIN_VALUE 0;
		MAX_VALUE 9999;
	}
	CONSTANT_UNIT "ms";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0526
	}
}

COMMAND READ_P0526
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0526 }
	}
}

METHOD SET_PAR_NUMBER_0526
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 526;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0526 LIKE READ_P0526
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 14, P0526 }
		REPLY { }
	}
}

VARIABLE P0527
{
	LABEL "P0527 PID Action Type|es|P0527 Tipo de Accin";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Direct|es|Directo " },
		{ 1, "Reverse|es|Reverso " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0527
	}
}

COMMAND READ_P0527
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0527 }
	}
}

METHOD SET_PAR_NUMBER_0527
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 527;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0527 LIKE READ_P0527
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 15, P0527 }
		REPLY { }
	}
}

VARIABLE P0528
{
	LABEL "P0528 VP Scale Factor|es|P0528 Escala Indicacin VP";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1000;
		MIN_VALUE 10;
		MAX_VALUE 30000;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0528
	}
}

COMMAND READ_P0528
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0528 }
	}
}

METHOD SET_PAR_NUMBER_0528
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 528;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0528 LIKE READ_P0528
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 16, P0528 }
		REPLY { }
	}
}

VARIABLE P0529
{
	LABEL "P0529 VP Decimal Point |es|P0529 Forma Indicacin VP ";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "wxyz|es|wxyz" },
		{ 1, "wxy.z|es|wxy.z" },
		{ 2, "wx.yz|es|wx.yz" },
		{ 3, "w.xyz|es|w.xyz" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0529
	}
}

COMMAND READ_P0529
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0529 }
	}
}

METHOD SET_PAR_NUMBER_0529
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 529;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0529 LIKE READ_P0529
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 17, P0529 }
		REPLY { }
	}
}

VARIABLE P0533
{
	LABEL "P0533 PVx Value|es|P0533 Valor VPx";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 90;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0533
	}
}

COMMAND READ_P0533
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0533 }
	}
}

METHOD SET_PAR_NUMBER_0533
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 533;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0533 LIKE READ_P0533
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 21, P0533 }
		REPLY { }
	}
}

VARIABLE P0535
{
	LABEL "P0535 Wake Up Band|es|P0535 Faja para Reactivar";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{
		SCALING_FACTOR 0.1;
		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0535
	}
}

COMMAND READ_P0535
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0535 }
	}
}

METHOD SET_PAR_NUMBER_0535
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 535;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0535 LIKE READ_P0535
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 23, P0535 }
		REPLY { }
	}
}

VARIABLE P0536
{
	LABEL "P0536 P0525 Autom. Setting|es|P0536 Ajuste autom. P0525";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Off |es|Inactivo" },
		{ 1, "On|es|Activo" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0536
	}
}

COMMAND READ_P0536
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0536 }
	}
}

METHOD SET_PAR_NUMBER_0536
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 536;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0536 LIKE READ_P0536
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 24, P0536 }
		REPLY { }
	}
}

VARIABLE P0680
{
	LABEL "P0680 Logical Status|es|P0680 Estado Lgico";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "Not Used|es|Reservado" },
		{ 0x0002, "Run Command|es|Comando Gira" },
		{ 0x000C, "Not Used|es|Reservado" },
		{ 0x0010, "Quick Stop|es|Parada Rapida" },
		{ 0x0020, "2nd Ramp|es|2 Rampa" },
		{ 0x0040, "Config. Mode|es|Modo Config." },
		{ 0x0080, "Alarm|es|Alarma" },
		{ 0x0100, "Running|es|Girando" },
		{ 0x0200, "Enabled|es|Habilitado" },
		{ 0x0400, "Forward|es|Horario" },
		{ 0x0800, "JOG|es|JOG" },
		{ 0x1000, "Remote|es|Remoto" },
		{ 0x2000, "Sub voltage|es|Subtensin" },
		{ 0x4000, "Automatic(PID)|es|Automtico(PID)" },
		{ 0x8000, "Fault|es|Falla" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0680
	}
}

COMMAND READ_P0680
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0680 }
	}
}

METHOD SET_PAR_NUMBER_0680
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 680;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0681
{
	LABEL "P0681 Speed in 13 bits|es|P0681 Velocidad 13 bits";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0681
	}
}

COMMAND READ_P0681
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0681 }
	}
}

METHOD SET_PAR_NUMBER_0681
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 681;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0682
{
	LABEL "P0682 Serial/USB Control|es|P0682 Control Serial/USB";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "Ramp Enable|es|Habilita Rampa" },
		{ 0x0002, "General Enable|es|Habilita General" },
		{ 0x0004, "Run Forward|es|Girar Horario" },
		{ 0x0008, "JOG Enable|es|Habilita JOG" },
		{ 0x0010, "Remote|es|Remoto" },
		{ 0x0020, "2nd Ramp|es|2 Rampa" },
		{ 0x0040, "Quick Stop|es|Parada Rapida" },
		{ 0x0080, "Fault Reset|es|Reset de Falla" },
		{ 0xFF00, "Not Used|es|Reservado" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0682
	}
}

COMMAND READ_P0682
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0682 }
	}
}

METHOD SET_PAR_NUMBER_0682
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 682;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0683
{
	LABEL "P0683 Serial/USB Speed Ref.|es|P0683 Ref. Vel. Serial/USB";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0683
	}
}

COMMAND READ_P0683
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0683 }
	}
}

METHOD SET_PAR_NUMBER_0683
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 683;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0684
{
	LABEL "P0684 CO/DN/PB Control|es|P0684 Control CANopen/DNet";
	CLASS CONTAINED;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "Ramp Enable|es|Habilita Rampa" },
		{ 0x0002, "General Enable|es|Habilita General" },
		{ 0x0004, "Run Forward|es|Girar Horario" },
		{ 0x0008, "JOG Enable|es|Habilita JOG" },
		{ 0x0010, "Remote|es|Remoto" },
		{ 0x0020, "2nd Ramp|es|2 Rampa" },
		{ 0x0040, "Quick Stop|es|Parada Rapida" },
		{ 0x0080, "Fault Reset|es|Reset de Falla" },
		{ 0xFF00, "Not Used|es|Reservado" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0684
	}
}

COMMAND READ_P0684
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0684 }
	}
}

METHOD SET_PAR_NUMBER_0684
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 684;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0684 LIKE READ_P0684
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 172, P0684 }
		REPLY { }
	}
}

VARIABLE P0685
{
	LABEL "P0685 CO/DN/PB Speed Ref|es|P0685 Ref. Vel. CANop./DNet";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0685
	}
}

COMMAND READ_P0685
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0685 }
	}
}

METHOD SET_PAR_NUMBER_0685
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 685;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0685 LIKE READ_P0685
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 173, P0685 }
		REPLY { }
	}
}

VARIABLE P0690
{
	LABEL "P0690 Logical Status|es|P0690 Estado Lgico";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x000F, "Not Used|es|Reservado" },
		{ 0x0010, "Force Low Fs |es|Reduccin Fs" },
		{ 0x0020, "Sleep State |es|Estado de Reposo" },
		{ 0x0040, "Deceleration Ramp|es|Rampa de Desaceleracin" },
		{ 0x0080, "Acceleration Ramp|es|Rampa de Aceleracin" },
		{ 0x0100, "Freeze Ramp|es|Rampa Congelada" },
		{ 0x0200, "Set point Ok|es|Setpoint Ok" },
		{ 0x0400, "DC Link Regulation|es|Regulacin link CC" },
		{ 0x0800, "50Hz Config|es|Config. en 50Hz" },
		{ 0x1000, "Ride Through|es|Ride Through" },
		{ 0x2000, "Flying Start |es|Flying Start " },
		{ 0x4000, "DC-Braking|es|Frenado CC" },
		{ 0x8000, "PWM|es|Pulsos PWM" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0690
	}
}

COMMAND READ_P0690
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0690 }
	}
}

METHOD SET_PAR_NUMBER_0690
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 690;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0695
{
	LABEL "P0695 DOx Value|es|P0695 Valor para DOx";
	CLASS CONTAINED;
	TYPE BIT_ENUMERATED(2)
	{
		{ 0x0001, "DO1|es|DO1" },
		{ 0x0002, "DO2|es|DO2" },
		{ 0x0004, "DO3|es|DO3" },
		{ 0x0008, "DO4|es|DO4" },
		{ 0x0010, "DO5|es|DO5" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0695
	}
}

COMMAND READ_P0695
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0695 }
	}
}

METHOD SET_PAR_NUMBER_0695
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 695;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0695 LIKE READ_P0695
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 183, P0695 }
		REPLY { }
	}
}

VARIABLE P0696
{
	LABEL "P0696 AOx Value 1|es|P0696 Valor 1 para AOx";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0696
	}
}

COMMAND READ_P0696
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0696 }
	}
}

METHOD SET_PAR_NUMBER_0696
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 696;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0696 LIKE READ_P0696
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 184, P0696 }
		REPLY { }
	}
}

VARIABLE P0697
{
	LABEL "P0697 AOx Value 2|es|P0697 Valor 2 para AOx";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0697
	}
}

COMMAND READ_P0697
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0697 }
	}
}

METHOD SET_PAR_NUMBER_0697
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 697;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0697 LIKE READ_P0697
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 185, P0697 }
		REPLY { }
	}
}

VARIABLE P0698
{
	LABEL "P0698 AOx Value 3|es|P0698 Valor 3 para AOx";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0698
	}
}

COMMAND READ_P0698
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0698 }
	}
}

METHOD SET_PAR_NUMBER_0698
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 698;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0698 LIKE READ_P0698
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 186, P0698 }
		REPLY { }
	}
}

VARIABLE P0700
{
	LABEL "P0700 CAN Protocol|es|P0700 Protocolo CAN";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 1, "CANopen|es|CANopen" },
		{ 2, "DeviceNet|es|DeviceNet" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0700
	}
}

COMMAND READ_P0700
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0700 }
	}
}

METHOD SET_PAR_NUMBER_0700
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 700;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0700 LIKE READ_P0700
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 188, P0700 }
		REPLY { }
	}
}

VARIABLE P0701
{
	LABEL "P0701 CAN Address|es|P0701 Direccin CAN";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 63;
		MIN_VALUE 0;
		MAX_VALUE 127;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0701
	}
}

COMMAND READ_P0701
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0701 }
	}
}

METHOD SET_PAR_NUMBER_0701
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 701;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0701 LIKE READ_P0701
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 189, P0701 }
		REPLY { }
	}
}

VARIABLE P0702
{
	LABEL "P0702 CAN Baud Rate|es|P0702 Tasa Comunicacin CAN";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "1 Mbps/Auto|es|1 Mbps/Auto" },
		{ 1, "Reserved/Auto|es|Reservado/Auto" },
		{ 2, "500 Kbps|es|500 Kbps" },
		{ 3, "250 Kbps|es|250 Kbps" },
		{ 4, "125 Kbps|es|125 Kbps" },
		{ 5, "100 Kbps/Auto|es|100 Kbps/Auto" },
		{ 6, "50 Kbps/Auto|es|50 Kbps/Auto" },
		{ 7, "20 Kbps/Auto|es|20 Kbps/Auto" },
		{ 8, "10 Kbps/Auto|es|10 Kbps/Auto" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0702
	}
}

COMMAND READ_P0702
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0702 }
	}
}

METHOD SET_PAR_NUMBER_0702
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 702;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0702 LIKE READ_P0702
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 190, P0702 }
		REPLY { }
	}
}

VARIABLE P0703
{
	LABEL "P0703 Bus Off Reset|es|P0703 Reset de Bus Off";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Manual|es|Manual" },
		{ 1, "Automatic|es|Automtico" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0703
	}
}

COMMAND READ_P0703
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0703 }
	}
}

METHOD SET_PAR_NUMBER_0703
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 703;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0703 LIKE READ_P0703
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 191, P0703 }
		REPLY { }
	}
}

VARIABLE P0705
{
	LABEL "P0705 CAN Controller Status|es|P0705 Estado ControladorCAN";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|Deshabilitado" },
		{ 1, "Auto-baud|es|Auto-baud" },
		{ 2, "CAN Enabled|es|CAN Activo" },
		{ 3, "Warning|es|Warning" },
		{ 4, "Error Passive|es|Error Passive" },
		{ 5, "Bus Off|es|Bus Off" },
		{ 6, "No Bus Power|es|No Alimentado" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0705
	}
}

COMMAND READ_P0705
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0705 }
	}
}

METHOD SET_PAR_NUMBER_0705
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 705;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0706
{
	LABEL "P0706 RX CAN Telegrams|es|P0706 Telegramas CAN RX";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0706
	}
}

COMMAND READ_P0706
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0706 }
	}
}

METHOD SET_PAR_NUMBER_0706
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 706;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0707
{
	LABEL "P0707 TX CAN Telegrams|es|P0707 Telegramas CAN TX";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0707
	}
}

COMMAND READ_P0707
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0707 }
	}
}

METHOD SET_PAR_NUMBER_0707
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 707;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0708
{
	LABEL "P0708 Bus Off Counter|es|P0708 Contador de Bus Off";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0708
	}
}

COMMAND READ_P0708
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0708 }
	}
}

METHOD SET_PAR_NUMBER_0708
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 708;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0709
{
	LABEL "P0709 CAN Lost Messages|es|P0709 Mensajes CAN Perdidas";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0709
	}
}

COMMAND READ_P0709
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0709 }
	}
}

METHOD SET_PAR_NUMBER_0709
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 709;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0710
{
	LABEL "P0710 DNet I/O instances|es|P0710 Instancias I/O Dnet";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "ODVA Basic 2W|es|ODVA Basic 2W" },
		{ 1, "ODVA Extend 2W|es|ODVA Extend 2W" },
		{ 2, "Manuf.Spec. 2W|es|Especif.Fab.2W" },
		{ 3, "Manuf.Spec. 3W|es|Especif.Fab.3W" },
		{ 4, "Manuf.Spec. 4W|es|Especif.Fab.4W" },
		{ 5, "Manuf.Spec. 5W|es|Especif.Fab.5W" },
		{ 6, "Manuf.Spec. 6W|es|Especif.Fab.6W" }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0710
	}
}

COMMAND READ_P0710
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0710 }
	}
}

METHOD SET_PAR_NUMBER_0710
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 710;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0710 LIKE READ_P0710
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 198, P0710 }
		REPLY { }
	}
}

VARIABLE P0711
{
	LABEL "P0711 DNet Read Word #3|es|P0711 Lectura #3 DeviceNet";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0711
	}
}

COMMAND READ_P0711
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0711 }
	}
}

METHOD SET_PAR_NUMBER_0711
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 711;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0711 LIKE READ_P0711
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 199, P0711 }
		REPLY { }
	}
}

VARIABLE P0712
{
	LABEL "P0712 DNet Read Word #4|es|P0712 Lectura #4 DeviceNet";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0712
	}
}

COMMAND READ_P0712
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0712 }
	}
}

METHOD SET_PAR_NUMBER_0712
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 712;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0712 LIKE READ_P0712
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 200, P0712 }
		REPLY { }
	}
}

VARIABLE P0713
{
	LABEL "P0713 DNet Read Word #5|es|P0713 Lectura #5 DeviceNet";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0713
	}
}

COMMAND READ_P0713
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0713 }
	}
}

METHOD SET_PAR_NUMBER_0713
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 713;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0713 LIKE READ_P0713
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 201, P0713 }
		REPLY { }
	}
}

VARIABLE P0714
{
	LABEL "P0714 DNet Read Word #6|es|P0714 Lectura #6 DeviceNet";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0714
	}
}

COMMAND READ_P0714
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0714 }
	}
}

METHOD SET_PAR_NUMBER_0714
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 714;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0714 LIKE READ_P0714
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 202, P0714 }
		REPLY { }
	}
}

VARIABLE P0715
{
	LABEL "P0715 DNet Write Word #3|es|P0715 Escrita #3 DeviceNet";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0715
	}
}

COMMAND READ_P0715
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0715 }
	}
}

METHOD SET_PAR_NUMBER_0715
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 715;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0715 LIKE READ_P0715
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 203, P0715 }
		REPLY { }
	}
}

VARIABLE P0716
{
	LABEL "P0716 DNet Write Word #4|es|P0716 Escrita #4 DeviceNet";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0716
	}
}

COMMAND READ_P0716
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0716 }
	}
}

METHOD SET_PAR_NUMBER_0716
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 716;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0716 LIKE READ_P0716
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 204, P0716 }
		REPLY { }
	}
}

VARIABLE P0717
{
	LABEL "P0717 DNet Write Word #5|es|P0717 Escrita #5 DeviceNet";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0717
	}
}

COMMAND READ_P0717
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0717 }
	}
}

METHOD SET_PAR_NUMBER_0717
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 717;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0717 LIKE READ_P0717
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 205, P0717 }
		REPLY { }
	}
}

VARIABLE P0718
{
	LABEL "P0718 DNet Write Word #6|es|P0718 Escrita #6 DeviceNet";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0718
	}
}

COMMAND READ_P0718
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0718 }
	}
}

METHOD SET_PAR_NUMBER_0718
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 718;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0718 LIKE READ_P0718
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 206, P0718 }
		REPLY { }
	}
}

VARIABLE P0719
{
	LABEL "P0719 DNet Network Status|es|P0719 Estado Red DeviceNet";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Offline|es|Offline" },
		{ 1, "OnLine,NotConn|es|OnLine,No Con." },
		{ 2, "OnLine,Conn|es|OnLine Conect." },
		{ 3, "Conn.Timed-out|es|ConexinExpir" },
		{ 4, "Link Failure|es|Falla Conexin" },
		{ 5, "Auto-Baud|es|Auto-Baud" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0719
	}
}

COMMAND READ_P0719
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0719 }
	}
}

METHOD SET_PAR_NUMBER_0719
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 719;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0720
{
	LABEL "P0720 DNet Master Status|es|P0720 Estado Maestro DNet";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Run|es|Run" },
		{ 1, "Idle|es|Idle" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0720
	}
}

COMMAND READ_P0720
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0720 }
	}
}

METHOD SET_PAR_NUMBER_0720
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 720;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0721
{
	LABEL "P0721 CANopen Comm. Status|es|P0721 Estado Com. CANopen";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|Deshabilitado" },
		{ 1, "Reserved|es|Reservado" },
		{ 2, "Comm. Enabled|es|Comunic. Hab." },
		{ 3, "ErrorCtrl.Enab|es|CtrlErroresHab" },
		{ 4, "Guarding Error|es|Error Guarding" },
		{ 5, "HeartbeatError|es|ErrorHeartbeat" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0721
	}
}

COMMAND READ_P0721
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0721 }
	}
}

METHOD SET_PAR_NUMBER_0721
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 721;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0722
{
	LABEL "P0722 CANopen Node State|es|P0722 Estado Nudo CANopen";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|Deshabilitado" },
		{ 1, "Initialization|es|Inicializacin" },
		{ 2, "Stopped|es|Parado" },
		{ 3, "Operational|es|Operacional" },
		{ 4, "PreOperational|es|Preoperacional" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0722
	}
}

COMMAND READ_P0722
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0722 }
	}
}

METHOD SET_PAR_NUMBER_0722
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 722;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0740
{
	LABEL "P0740 Profibus Comm. Status|es|P0740 Estado Com. Profibus";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "Disabled|es|Inactivo" },
		{ 1, "Access Error|es|Error Acceso" },
		{ 2, "Offline|es|Offline" },
		{ 3, "Config. Error|es|Error Config." },
		{ 4, "Param. Error|es|Error Parm." },
		{ 5, "Clear Mode|es|Modo Clear" },
		{ 6, "Online|es|Online" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0740
	}
}

COMMAND READ_P0740
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0740 }
	}
}

METHOD SET_PAR_NUMBER_0740
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 740;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0741
{
	LABEL "P0741 Profibus Data Profile|es|P0741 Perfil Datos Profibus";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "PROFIdrive|es|PROFIdrive" },
		{ 1, "Manufacturer|es|Fabricante" }
		DEFAULT_VALUE 1;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0741
	}
}

COMMAND READ_P0741
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0741 }
	}
}

METHOD SET_PAR_NUMBER_0741
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 741;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0741 LIKE READ_P0741
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 229, P0741 }
		REPLY { }
	}
}

VARIABLE P0742
{
	LABEL "P0742 Profibus Read Word #3|es|P0742 Lectura #3 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0742
	}
}

COMMAND READ_P0742
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0742 }
	}
}

METHOD SET_PAR_NUMBER_0742
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 742;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0742 LIKE READ_P0742
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 230, P0742 }
		REPLY { }
	}
}

VARIABLE P0743
{
	LABEL "P0743 Profibus Read Word #4|es|P0743 Lectura #4 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0743
	}
}

COMMAND READ_P0743
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0743 }
	}
}

METHOD SET_PAR_NUMBER_0743
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 743;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0743 LIKE READ_P0743
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 231, P0743 }
		REPLY { }
	}
}

VARIABLE P0744
{
	LABEL "P0744 Profibus Read Word #5|es|P0744 Lectura #5 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0744
	}
}

COMMAND READ_P0744
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0744 }
	}
}

METHOD SET_PAR_NUMBER_0744
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 744;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0744 LIKE READ_P0744
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 232, P0744 }
		REPLY { }
	}
}

VARIABLE P0745
{
	LABEL "P0745 Profibus Read Word #6|es|P0745 Lectura #6 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0745
	}
}

COMMAND READ_P0745
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0745 }
	}
}

METHOD SET_PAR_NUMBER_0745
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 745;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0745 LIKE READ_P0745
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 233, P0745 }
		REPLY { }
	}
}

VARIABLE P0746
{
	LABEL "P0746 Profibus Read Word #7|es|P0746 Lectura #7 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0746
	}
}

COMMAND READ_P0746
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0746 }
	}
}

METHOD SET_PAR_NUMBER_0746
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 746;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0746 LIKE READ_P0746
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 234, P0746 }
		REPLY { }
	}
}

VARIABLE P0747
{
	LABEL "P0747 Profibus Read Word #8|es|P0747 Lectura #8 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0747
	}
}

COMMAND READ_P0747
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0747 }
	}
}

METHOD SET_PAR_NUMBER_0747
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 747;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0747 LIKE READ_P0747
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 235, P0747 }
		REPLY { }
	}
}

VARIABLE P0750
{
	LABEL "P0750 Profibus Write Word#3|es|P0750 Escrita #3 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0750
	}
}

COMMAND READ_P0750
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0750 }
	}
}

METHOD SET_PAR_NUMBER_0750
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 750;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0750 LIKE READ_P0750
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 238, P0750 }
		REPLY { }
	}
}

VARIABLE P0751
{
	LABEL "P0751 Profibus Write Word#4|es|P0751 Escrita #4 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0751
	}
}

COMMAND READ_P0751
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0751 }
	}
}

METHOD SET_PAR_NUMBER_0751
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 751;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0751 LIKE READ_P0751
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 239, P0751 }
		REPLY { }
	}
}

VARIABLE P0752
{
	LABEL "P0752 Profibus Write Word#5|es|P0752 Escrita #5 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0752
	}
}

COMMAND READ_P0752
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0752 }
	}
}

METHOD SET_PAR_NUMBER_0752
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 752;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0752 LIKE READ_P0752
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 240, P0752 }
		REPLY { }
	}
}

VARIABLE P0753
{
	LABEL "P0753 Profibus Write Word#6|es|P0753 Escrita #6 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0753
	}
}

COMMAND READ_P0753
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0753 }
	}
}

METHOD SET_PAR_NUMBER_0753
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 753;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0753 LIKE READ_P0753
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 241, P0753 }
		REPLY { }
	}
}

VARIABLE P0754
{
	LABEL "P0754 Profibus Write Word#7|es|P0754 Escrita #7 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0754
	}
}

COMMAND READ_P0754
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0754 }
	}
}

METHOD SET_PAR_NUMBER_0754
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 754;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0754 LIKE READ_P0754
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 242, P0754 }
		REPLY { }
	}
}

VARIABLE P0755
{
	LABEL "P0755 Profibus Write Word#8|es|P0755 Escrita #8 Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 1199;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0755
	}
}

COMMAND READ_P0755
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0755 }
	}
}

METHOD SET_PAR_NUMBER_0755
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 755;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0755 LIKE READ_P0755
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 2, 243, P0755 }
		REPLY { }
	}
}

VARIABLE P0918
{
	LABEL "P0918 Profibus Address|es|P0918 Direccin Profibus";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 1;
		MIN_VALUE 1;
		MAX_VALUE 126;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0918
	}
}

COMMAND READ_P0918
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0918 }
	}
}

METHOD SET_PAR_NUMBER_0918
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 918;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0918 LIKE READ_P0918
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 150, P0918 }
		REPLY { }
	}
}

VARIABLE P0922
{
	LABEL "P0922 Profibus Teleg. Sel.|es|P0922 Sel. Teleg. Profibus";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 2, "Std. Teleg. 1|es|Teleg.Padro 1" },
		{ 3, "Telegram 103|es|Telegrama 100" },
		{ 4, "Telegram 104|es|Telegrama 101" },
		{ 5, "Telegram 105|es|Telegrama 102" },
		{ 6, "Telegram 106|es|Telegrama 103" },
		{ 7, "Telegram 107|es|Telegrama 104" },
		{ 8, "Telegram 108|es|Telegrama 105" }
		DEFAULT_VALUE 2;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0922
	}
}

COMMAND READ_P0922
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0922 }
	}
}

METHOD SET_PAR_NUMBER_0922
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 922;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P0922 LIKE READ_P0922
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 154, P0922 }
		REPLY { }
	}
}

VARIABLE P0963
{
	LABEL "P0963 Profibus Baud Rate|es|P0963 Taxa Comunic.Profibus";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "9.6 kbit/s|es|9.6 kbit/s" },
		{ 1, "19.2 kbit/s|es|19.2 kbit/s" },
		{ 2, "93.75 kbit/s|es|93.75 kbit/s" },
		{ 3, "187.5 kbit/s|es|187.5 kbit/s" },
		{ 4, "500 kbit/s|es|500 kbit/s" },
		{ 5, "Not Detected|es|No Detectada" },
		{ 6, "1500 kbit/s|es|1500 kbit/s" },
		{ 7, "3000 kbit/s|es|3000 kbit/s" },
		{ 8, "6000 kbit/s|es|6000 kbit/s" },
		{ 9, "12000 kbit/s|es|12000 kbit/s" },
		{ 10, "Reserved|es|Reservado" },
		{ 11, "45.45 kbit/s|es|45.45 kbit/s" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0963
	}
}

COMMAND READ_P0963
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0963 }
	}
}

METHOD SET_PAR_NUMBER_0963
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 963;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0967
{
	LABEL "P0967 Control Word 1|es|P0967 Palavra de Control 1";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0967
	}
}

COMMAND READ_P0967
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0967 }
	}
}

METHOD SET_PAR_NUMBER_0967
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 967;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P0968
{
	LABEL "P0968 Status Word 1|es|P0968 Palavra de Status 1";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_0968
	}
}

COMMAND READ_P0968
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P0968 }
	}
}

METHOD SET_PAR_NUMBER_0968
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 968;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1000
{
	LABEL "P1000 SoftPLC Status|es|P1000 Estado de la SoftPLC";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE ENUMERATED(2)
	{
		{ 0, "No Applicative|es|Sin Aplicativo" },
		{ 1, "Installing App.|es|Instalando Aplic." },
		{ 2, "Incompatible App.|es|Aplic. Incompleto" },
		{ 3, "Stopped App.|es|Aplic. Parado" },
		{ 4, "App. Running|es|Aplic. Ejecutando" }
		DEFAULT_VALUE 0;
	}
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1000
	}
}

COMMAND READ_P1000
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1000 }
	}
}

METHOD SET_PAR_NUMBER_1000
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1000;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1001
{
	LABEL "P1001 SoftPLC Command|es|P1001 Comando para SoftPLC";
	CLASS CONTAINED;
	TYPE ENUMERATED(2)
	{
		{ 0, "Stop Application|es|Para Aplic." },
		{ 1, "Run Application|es|Ejecuta Aplic." },
		{ 2, "Delete Application|es|Borra Aplic. " }
		DEFAULT_VALUE 0;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1001
	}
}

COMMAND READ_P1001
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1001 }
	}
}

METHOD SET_PAR_NUMBER_1001
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1001;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1001 LIKE READ_P1001
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 233, P1001 }
		REPLY { }
	}
}

VARIABLE P1002
{
	LABEL "P1002 Scan Cycle Time|es|P1002 Tiempo Ciclo de Ejec.";
	CLASS CONTAINED & DIAGNOSTIC & DYNAMIC;
	TYPE UNSIGNED_INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE 0;
		MAX_VALUE 65535;
	}
	CONSTANT_UNIT "ms";
	HANDLING READ;
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1002
	}
}

COMMAND READ_P1002
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1002 }
	}
}

METHOD SET_PAR_NUMBER_1002
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1002;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

VARIABLE P1010
{
	LABEL "P1010 SoftPLC Parameter 1|es|P1010 Parmetro SoftPLC 1";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1010
	}
}

COMMAND READ_P1010
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1010 }
	}
}

METHOD SET_PAR_NUMBER_1010
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1010;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1010 LIKE READ_P1010
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 242, P1010 }
		REPLY { }
	}
}

VARIABLE P1011
{
	LABEL "P1011 SoftPLC Parameter 2|es|P1011 Parmetro SoftPLC 2";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1011
	}
}

COMMAND READ_P1011
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1011 }
	}
}

METHOD SET_PAR_NUMBER_1011
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1011;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1011 LIKE READ_P1011
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 243, P1011 }
		REPLY { }
	}
}

VARIABLE P1012
{
	LABEL "P1012 SoftPLC Parameter 3|es|P1012 Parmetro SoftPLC 3";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1012
	}
}

COMMAND READ_P1012
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1012 }
	}
}

METHOD SET_PAR_NUMBER_1012
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1012;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1012 LIKE READ_P1012
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 244, P1012 }
		REPLY { }
	}
}

VARIABLE P1013
{
	LABEL "P1013 SoftPLC Parameter 4|es|P1013 Parmetro SoftPLC 4";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1013
	}
}

COMMAND READ_P1013
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1013 }
	}
}

METHOD SET_PAR_NUMBER_1013
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1013;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1013 LIKE READ_P1013
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 245, P1013 }
		REPLY { }
	}
}

VARIABLE P1014
{
	LABEL "P1014 SoftPLC Parameter 5|es|P1014 Parmetro SoftPLC 5";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1014
	}
}

COMMAND READ_P1014
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1014 }
	}
}

METHOD SET_PAR_NUMBER_1014
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1014;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1014 LIKE READ_P1014
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 246, P1014 }
		REPLY { }
	}
}

VARIABLE P1015
{
	LABEL "P1015 SoftPLC Parameter 6|es|P1015 Parmetro SoftPLC 6";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1015
	}
}

COMMAND READ_P1015
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1015 }
	}
}

METHOD SET_PAR_NUMBER_1015
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1015;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1015 LIKE READ_P1015
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 247, P1015 }
		REPLY { }
	}
}

VARIABLE P1016
{
	LABEL "P1016 SoftPLC Parameter 7|es|P1016 Parmetro SoftPLC 7";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1016
	}
}

COMMAND READ_P1016
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1016 }
	}
}

METHOD SET_PAR_NUMBER_1016
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1016;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1016 LIKE READ_P1016
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 248, P1016 }
		REPLY { }
	}
}

VARIABLE P1017
{
	LABEL "P1017 SoftPLC Parameter 8|es|P1017 Parmetro SoftPLC 8";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1017
	}
}

COMMAND READ_P1017
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1017 }
	}
}

METHOD SET_PAR_NUMBER_1017
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1017;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1017 LIKE READ_P1017
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 249, P1017 }
		REPLY { }
	}
}

VARIABLE P1018
{
	LABEL "P1018 SoftPLC Parameter 9|es|P1018 Parmetro SoftPLC 9";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1018
	}
}

COMMAND READ_P1018
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1018 }
	}
}

METHOD SET_PAR_NUMBER_1018
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1018;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1018 LIKE READ_P1018
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 250, P1018 }
		REPLY { }
	}
}

VARIABLE P1019
{
	LABEL "P1019 SoftPLC Parameter 10|es|P1019 Parmetro SoftPLC 10";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1019
	}
}

COMMAND READ_P1019
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1019 }
	}
}

METHOD SET_PAR_NUMBER_1019
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1019;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1019 LIKE READ_P1019
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 251, P1019 }
		REPLY { }
	}
}

VARIABLE P1020
{
	LABEL "P1020 SoftPLC Parameter 11|es|P1020 Parmetro SoftPLC 11";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1020
	}
}

COMMAND READ_P1020
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1020 }
	}
}

METHOD SET_PAR_NUMBER_1020
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1020;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1020 LIKE READ_P1020
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 252, P1020 }
		REPLY { }
	}
}

VARIABLE P1021
{
	LABEL "P1021 SoftPLC Parameter 12|es|P1021 Parmetro SoftPLC 12";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1021
	}
}

COMMAND READ_P1021
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1021 }
	}
}

METHOD SET_PAR_NUMBER_1021
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1021;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1021 LIKE READ_P1021
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 253, P1021 }
		REPLY { }
	}
}

VARIABLE P1022
{
	LABEL "P1022 SoftPLC Parameter 13|es|P1022 Parmetro SoftPLC 13";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1022
	}
}

COMMAND READ_P1022
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1022 }
	}
}

METHOD SET_PAR_NUMBER_1022
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1022;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1022 LIKE READ_P1022
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 254, P1022 }
		REPLY { }
	}
}

VARIABLE P1023
{
	LABEL "P1023 SoftPLC Parameter 14|es|P1023 Parmetro SoftPLC 14";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1023
	}
}

COMMAND READ_P1023
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1023 }
	}
}

METHOD SET_PAR_NUMBER_1023
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1023;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1023 LIKE READ_P1023
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 3, 255, P1023 }
		REPLY { }
	}
}

VARIABLE P1024
{
	LABEL "P1024 SoftPLC Parameter 15|es|P1024 Parmetro SoftPLC 15";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1024
	}
}

COMMAND READ_P1024
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1024 }
	}
}

METHOD SET_PAR_NUMBER_1024
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1024;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1024 LIKE READ_P1024
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 0, P1024 }
		REPLY { }
	}
}

VARIABLE P1025
{
	LABEL "P1025 SoftPLC Parameter 16|es|P1025 Parmetro SoftPLC 16";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1025
	}
}

COMMAND READ_P1025
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1025 }
	}
}

METHOD SET_PAR_NUMBER_1025
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1025;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1025 LIKE READ_P1025
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 1, P1025 }
		REPLY { }
	}
}

VARIABLE P1026
{
	LABEL "P1026 SoftPLC Parameter 17|es|P1026 Parmetro SoftPLC 17";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1026
	}
}

COMMAND READ_P1026
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1026 }
	}
}

METHOD SET_PAR_NUMBER_1026
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1026;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1026 LIKE READ_P1026
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 2, P1026 }
		REPLY { }
	}
}

VARIABLE P1027
{
	LABEL "P1027 SoftPLC Parameter 18|es|P1027 Parmetro SoftPLC 18";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1027
	}
}

COMMAND READ_P1027
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1027 }
	}
}

METHOD SET_PAR_NUMBER_1027
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1027;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1027 LIKE READ_P1027
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 3, P1027 }
		REPLY { }
	}
}

VARIABLE P1028
{
	LABEL "P1028 SoftPLC Parameter 19|es|P1028 Parmetro SoftPLC 19";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1028
	}
}

COMMAND READ_P1028
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1028 }
	}
}

METHOD SET_PAR_NUMBER_1028
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1028;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1028 LIKE READ_P1028
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 4, P1028 }
		REPLY { }
	}
}

VARIABLE P1029
{
	LABEL "P1029 SoftPLC Parameter 20|es|P1029 Parmetro SoftPLC 20";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1029
	}
}

COMMAND READ_P1029
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1029 }
	}
}

METHOD SET_PAR_NUMBER_1029
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1029;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1029 LIKE READ_P1029
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 5, P1029 }
		REPLY { }
	}
}

VARIABLE P1030
{
	LABEL "P1030 SoftPLC Parameter 21|es|P1030 Parmetro SoftPLC 21";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1030
	}
}

COMMAND READ_P1030
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1030 }
	}
}

METHOD SET_PAR_NUMBER_1030
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1030;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1030 LIKE READ_P1030
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 6, P1030 }
		REPLY { }
	}
}

VARIABLE P1031
{
	LABEL "P1031 SoftPLC Parameter 22|es|P1031 Parmetro SoftPLC 22";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1031
	}
}

COMMAND READ_P1031
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1031 }
	}
}

METHOD SET_PAR_NUMBER_1031
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1031;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1031 LIKE READ_P1031
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 7, P1031 }
		REPLY { }
	}
}

VARIABLE P1032
{
	LABEL "P1032 SoftPLC Parameter 23|es|P1032 Parmetro SoftPLC 23";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1032
	}
}

COMMAND READ_P1032
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1032 }
	}
}

METHOD SET_PAR_NUMBER_1032
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1032;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1032 LIKE READ_P1032
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 8, P1032 }
		REPLY { }
	}
}

VARIABLE P1033
{
	LABEL "P1033 SoftPLC Parameter 24|es|P1033 Parmetro SoftPLC 24";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1033
	}
}

COMMAND READ_P1033
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1033 }
	}
}

METHOD SET_PAR_NUMBER_1033
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1033;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1033 LIKE READ_P1033
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 9, P1033 }
		REPLY { }
	}
}

VARIABLE P1034
{
	LABEL "P1034 SoftPLC Parameter 25|es|P1034 Parmetro SoftPLC 25";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1034
	}
}

COMMAND READ_P1034
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1034 }
	}
}

METHOD SET_PAR_NUMBER_1034
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1034;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1034 LIKE READ_P1034
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 10, P1034 }
		REPLY { }
	}
}

VARIABLE P1035
{
	LABEL "P1035 SoftPLC Parameter 26|es|P1035 Parmetro SoftPLC 26";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1035
	}
}

COMMAND READ_P1035
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1035 }
	}
}

METHOD SET_PAR_NUMBER_1035
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1035;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1035 LIKE READ_P1035
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 11, P1035 }
		REPLY { }
	}
}

VARIABLE P1036
{
	LABEL "P1036 SoftPLC Parameter 27|es|P1036 Parmetro SoftPLC 27";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1036
	}
}

COMMAND READ_P1036
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1036 }
	}
}

METHOD SET_PAR_NUMBER_1036
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1036;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1036 LIKE READ_P1036
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 12, P1036 }
		REPLY { }
	}
}

VARIABLE P1037
{
	LABEL "P1037 SoftPLC Parameter 28|es|P1037 Parmetro SoftPLC 28";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1037
	}
}

COMMAND READ_P1037
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1037 }
	}
}

METHOD SET_PAR_NUMBER_1037
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1037;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1037 LIKE READ_P1037
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 13, P1037 }
		REPLY { }
	}
}

VARIABLE P1038
{
	LABEL "P1038 SoftPLC Parameter 29|es|P1038 Parmetro SoftPLC 29";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1038
	}
}

COMMAND READ_P1038
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1038 }
	}
}

METHOD SET_PAR_NUMBER_1038
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1038;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1038 LIKE READ_P1038
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 14, P1038 }
		REPLY { }
	}
}

VARIABLE P1039
{
	LABEL "P1039 SoftPLC Parameter 30|es|P1039 Parmetro SoftPLC 30";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1039
	}
}

COMMAND READ_P1039
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1039 }
	}
}

METHOD SET_PAR_NUMBER_1039
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1039;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1039 LIKE READ_P1039
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 15, P1039 }
		REPLY { }
	}
}

VARIABLE P1040
{
	LABEL "P1040 SoftPLC Parameter 31|es|P1040 Parmetro SoftPLC 31";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1040
	}
}

COMMAND READ_P1040
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1040 }
	}
}

METHOD SET_PAR_NUMBER_1040
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1040;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1040 LIKE READ_P1040
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 16, P1040 }
		REPLY { }
	}
}

VARIABLE P1041
{
	LABEL "P1041 SoftPLC Parameter 32|es|P1041 Parmetro SoftPLC 32";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1041
	}
}

COMMAND READ_P1041
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1041 }
	}
}

METHOD SET_PAR_NUMBER_1041
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1041;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1041 LIKE READ_P1041
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 17, P1041 }
		REPLY { }
	}
}

VARIABLE P1042
{
	LABEL "P1042 SoftPLC Parameter 33|es|P1042 Parmetro SoftPLC 33";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1042
	}
}

COMMAND READ_P1042
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1042 }
	}
}

METHOD SET_PAR_NUMBER_1042
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1042;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1042 LIKE READ_P1042
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 18, P1042 }
		REPLY { }
	}
}

VARIABLE P1043
{
	LABEL "P1043 SoftPLC Parameter 34|es|P1043 Parmetro SoftPLC 34";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1043
	}
}

COMMAND READ_P1043
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1043 }
	}
}

METHOD SET_PAR_NUMBER_1043
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1043;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1043 LIKE READ_P1043
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 19, P1043 }
		REPLY { }
	}
}

VARIABLE P1044
{
	LABEL "P1044 SoftPLC Parameter 35|es|P1044 Parmetro SoftPLC 35";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1044
	}
}

COMMAND READ_P1044
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1044 }
	}
}

METHOD SET_PAR_NUMBER_1044
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1044;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1044 LIKE READ_P1044
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 20, P1044 }
		REPLY { }
	}
}

VARIABLE P1045
{
	LABEL "P1045 SoftPLC Parameter 36|es|P1045 Parmetro SoftPLC 36";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1045
	}
}

COMMAND READ_P1045
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1045 }
	}
}

METHOD SET_PAR_NUMBER_1045
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1045;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1045 LIKE READ_P1045
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 21, P1045 }
		REPLY { }
	}
}

VARIABLE P1046
{
	LABEL "P1046 SoftPLC Parameter 37|es|P1046 Parmetro SoftPLC 37";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1046
	}
}

COMMAND READ_P1046
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1046 }
	}
}

METHOD SET_PAR_NUMBER_1046
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1046;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1046 LIKE READ_P1046
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 22, P1046 }
		REPLY { }
	}
}

VARIABLE P1047
{
	LABEL "P1047 SoftPLC Parameter 38|es|P1047 Parmetro SoftPLC 38";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1047
	}
}

COMMAND READ_P1047
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1047 }
	}
}

METHOD SET_PAR_NUMBER_1047
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1047;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1047 LIKE READ_P1047
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 23, P1047 }
		REPLY { }
	}
}

VARIABLE P1048
{
	LABEL "P1048 SoftPLC Parameter 39|es|P1048 Parmetro SoftPLC 39";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1048
	}
}

COMMAND READ_P1048
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1048 }
	}
}

METHOD SET_PAR_NUMBER_1048
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1048;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1048 LIKE READ_P1048
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 24, P1048 }
		REPLY { }
	}
}

VARIABLE P1049
{
	LABEL "P1049 SoftPLC Parameter 40|es|P1049 Parmetro SoftPLC 40";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1049
	}
}

COMMAND READ_P1049
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1049 }
	}
}

METHOD SET_PAR_NUMBER_1049
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1049;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1049 LIKE READ_P1049
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 25, P1049 }
		REPLY { }
	}
}

VARIABLE P1050
{
	LABEL "P1050 SoftPLC Parameter 41|es|P1050 Parmetro SoftPLC 41";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1050
	}
}

COMMAND READ_P1050
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1050 }
	}
}

METHOD SET_PAR_NUMBER_1050
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1050;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1050 LIKE READ_P1050
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 26, P1050 }
		REPLY { }
	}
}

VARIABLE P1051
{
	LABEL "P1051 SoftPLC Parameter 42|es|P1051 Parmetro SoftPLC 42";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1051
	}
}

COMMAND READ_P1051
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1051 }
	}
}

METHOD SET_PAR_NUMBER_1051
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1051;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1051 LIKE READ_P1051
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 27, P1051 }
		REPLY { }
	}
}

VARIABLE P1052
{
	LABEL "P1052 SoftPLC Parameter 43|es|P1052 Parmetro SoftPLC 43";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1052
	}
}

COMMAND READ_P1052
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1052 }
	}
}

METHOD SET_PAR_NUMBER_1052
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1052;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1052 LIKE READ_P1052
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 28, P1052 }
		REPLY { }
	}
}

VARIABLE P1053
{
	LABEL "P1053 SoftPLC Parameter 44|es|P1053 Parmetro SoftPLC 44";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1053
	}
}

COMMAND READ_P1053
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1053 }
	}
}

METHOD SET_PAR_NUMBER_1053
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1053;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1053 LIKE READ_P1053
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 29, P1053 }
		REPLY { }
	}
}

VARIABLE P1054
{
	LABEL "P1054 SoftPLC Parameter 45|es|P1054 Parmetro SoftPLC 45";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1054
	}
}

COMMAND READ_P1054
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1054 }
	}
}

METHOD SET_PAR_NUMBER_1054
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1054;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1054 LIKE READ_P1054
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 30, P1054 }
		REPLY { }
	}
}

VARIABLE P1055
{
	LABEL "P1055 SoftPLC Parameter 46|es|P1055 Parmetro SoftPLC 46";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1055
	}
}

COMMAND READ_P1055
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1055 }
	}
}

METHOD SET_PAR_NUMBER_1055
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1055;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1055 LIKE READ_P1055
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 31, P1055 }
		REPLY { }
	}
}

VARIABLE P1056
{
	LABEL "P1056 SoftPLC Parameter 47|es|P1056 Parmetro SoftPLC 47";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1056
	}
}

COMMAND READ_P1056
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1056 }
	}
}

METHOD SET_PAR_NUMBER_1056
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1056;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1056 LIKE READ_P1056
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 32, P1056 }
		REPLY { }
	}
}

VARIABLE P1057
{
	LABEL "P1057 SoftPLC Parameter 48|es|P1057 Parmetro SoftPLC 48";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1057
	}
}

COMMAND READ_P1057
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1057 }
	}
}

METHOD SET_PAR_NUMBER_1057
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1057;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1057 LIKE READ_P1057
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 33, P1057 }
		REPLY { }
	}
}

VARIABLE P1058
{
	LABEL "P1058 SoftPLC Parameter 49|es|P1058 Parmetro SoftPLC 49";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1058
	}
}

COMMAND READ_P1058
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1058 }
	}
}

METHOD SET_PAR_NUMBER_1058
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1058;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1058 LIKE READ_P1058
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 34, P1058 }
		REPLY { }
	}
}

VARIABLE P1059
{
	LABEL "P1059 SoftPLC Parameter 50|es|P1059 Parmetro SoftPLC 50";
	CLASS CONTAINED;
	TYPE INTEGER(2)
	{

		DEFAULT_VALUE 0;
		MIN_VALUE -32768;
		MAX_VALUE 32767;
	}
	PRE_READ_ACTIONS
	{
		SET_PAR_NUMBER_1059
	}
}

COMMAND READ_P1059
{
	SLOT 0;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST { }
		REPLY { P1059 }
	}
}

METHOD SET_PAR_NUMBER_1059
{
	LABEL       "Set Parameter Number";
	DEFINITION
	{
		g_wParNumber = 1059;
		WriteCommand(WRITE_PAR_NUMBER);
	}
}

WRITE_P1059 LIKE READ_P1059
{
	REDEFINE OPERATION WRITE;
	REDEFINE TRANSACTION
	{
		REQUEST { 4, 35, P1059 }
		REPLY { }
	}
}











